BorderRadiusMix class final

Mix representation of BorderRadius.

Supports individual corner control with tokens.

Inheritance
Mixed-in types
Annotations
  • @Mixable.new(methods: GeneratedMixMethods.skipResolve)

Constructors

BorderRadiusMix({Radius? topLeft, Radius? topRight, Radius? bottomLeft, Radius? bottomRight})
BorderRadiusMix.all(Radius radius)
BorderRadiusMix.bottomLeft(Radius radius)
Creates with bottom-left corner.
factory
BorderRadiusMix.bottomRight(Radius radius)
Creates with bottom-right corner.
factory
BorderRadiusMix.circular(double radius)
Creates with circular radius.
factory
BorderRadiusMix.create({Prop<Radius>? topLeft, Prop<Radius>? topRight, Prop<Radius>? bottomLeft, Prop<Radius>? bottomRight})
const
BorderRadiusMix.elliptical(double xRadius, double yRadius)
Creates with elliptical radius.
factory
BorderRadiusMix.topLeft(Radius radius)
Creates with top-left corner.
factory
BorderRadiusMix.topRight(Radius radius)
Creates with top-right corner.
factory
BorderRadiusMix.value(BorderRadius borderRadius)
Creates from BorderRadius.

Properties

$bottomLeft Prop<Radius>?
final
$bottomRight Prop<Radius>?
final
$topLeft Prop<Radius>?
final
$topRight Prop<Radius>?
final
defaultValue BorderRadius
The default value to use when no explicit value is available.
no setteroverride
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
The key used to identify compatible types for merging.
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

bottomLeft(Radius radius) BorderRadiusMix
Copy with bottom-left radius.
override
bottomRight(Radius radius) BorderRadiusMix
Copy with bottom-right radius.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
merge(covariant BorderRadiusMix? other) BorderRadiusMix
Merges with another BorderRadiusMix.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) BorderRadius
Resolves this to a concrete value using the provided context.
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
topLeft(Radius radius) BorderRadiusMix
Copy with top-left radius.
override
topRight(Radius radius) BorderRadiusMix
Copy with top-right radius.
override
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited

Static Methods

maybeValue(BorderRadius? borderRadius) BorderRadiusMix?
Creates from nullable BorderRadius.
override