Box class

Box is equivalent to Flutter's Container, it provides styling capabilities through the Mix framework. It can be used to create visually styled boxes with decoration, padding, margins, transforms, and constraints.

You can use BoxStyler to create styles with a fluent API. Example:

final style = BoxStyler()
  .width(200)
  .height(100)
  .color(Colors.blue)
  .borderRounded(12)
  .padding(16);

Box(style: style, child: Text('Hello Mix'))
Inheritance

Constructors

Box({Style<BoxSpec> style = const IdentityStyle(BoxSpec()), StyleSpec<BoxSpec>? styleSpec, Key? key, Widget? child})
const

Properties

child Widget?
Child widget to display inside the box.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style<BoxSpec>
Style to apply to this widget.
finalinherited
styleSpec StyleSpec<BoxSpec>?
Direct spec to apply to this widget.
finalinherited

Methods

build(BuildContext context, BoxSpec spec) Widget
Builds the widget with the resolved spec.
override
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StyleWidget<BoxSpec>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited