BoxBorderMix<T extends BoxBorder> class sealed

Base class for Mix border types.

Common functionality with merging and type conversion.

Inheritance

Properties

$bottom Prop<BorderSide>?
final
$top Prop<BorderSide>?
final
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
isDirectional bool
no setter
isUniform bool
no setter
mergeKey Object
The key used to identify compatible types for merging.
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited
uniformBorderSide Prop<BorderSide>?
Gets border side if uniform, null otherwise.
no setter

Methods

getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
merge(covariant BoxBorderMix<T>? other) BoxBorderMix<T>
Merges this instance with other, with other taking precedence.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(BuildContext context) → T
Resolves this to a concrete value using the provided context.
inherited
toString() String
Overrides string representation for debugging and logging.
inherited

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited

Static Properties

none BorderMix
getter/setter pair

Static Methods

all(BorderSideMix side) BorderMix
bottom(BorderSideMix side) BorderMix
color(Color value) BorderMix
directional(BorderDirectionalMix mix) BorderDirectionalMix
end(BorderSideMix side) BorderDirectionalMix
horizontal(BorderSideMix side) BorderMix
left(BorderSideMix side) BorderMix
maybeValue<T extends BoxBorder>(T? border) BoxBorderMix<T>?
start(BorderSideMix side) BorderDirectionalMix
strokeAlign(double value) BorderMix
style(BorderStyle value) BorderMix
symmetric({BorderSideMix? vertical, BorderSideMix? horizontal}) BorderMix
Creates symmetric border with vertical/horizontal sides.
top(BorderSideMix side) BorderMix
tryToMerge(BoxBorderMix<BoxBorder>? a, BoxBorderMix<BoxBorder>? b) BoxBorderMix<BoxBorder>?
Merges border instances with type conversion.
value<T extends BoxBorder>(T border) BoxBorderMix<T>
vertical(BorderSideMix side) BorderMix
width(double value) BorderMix