getDiff method
Returns a map of properties that differ between this object and another.
Implementation
@override
Map<String, String> getDiff(Equatable other) {
if (this == other) return const {};
return propsDiff(props, other.props);
}
Returns a map of properties that differ between this object and another.
@override
Map<String, String> getDiff(Equatable other) {
if (this == other) return const {};
return propsDiff(props, other.props);
}