stringify property
bool
get
stringify
Whether to use a detailed string representation of the object.
Implementation
bool get stringify => true;
Whether to use a detailed string representation of the object.
bool get stringify => true;