IconButtonStyler class

Inheritance
Implemented types
Mixed-in types

Constructors

IconButtonStyler({BoxStyler? container, IconStyler? icon, SpinnerStyler? spinner, RemixBoxEffectsMix? containerEffects, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<IconButtonSpec>>? variants})
IconButtonStyler.alignment(AlignmentGeometry value)
factory
IconButtonStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
IconButtonStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
IconButtonStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
IconButtonStyler.border(BoxBorderMix<BoxBorder> value)
factory
IconButtonStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
factory
IconButtonStyler.clipBehavior(Clip value)
factory
IconButtonStyler.color(Color value)
factory
IconButtonStyler.constraints(BoxConstraintsMix value)
factory
IconButtonStyler.container(BoxStyler value)
factory
IconButtonStyler.containerEffects(RemixBoxEffectsMix value)
factory
IconButtonStyler.create({Prop<StyleSpec<BoxSpec>>? container, Prop<StyleSpec<IconSpec>>? icon, Prop<StyleSpec<SpinnerSpec>>? spinner, Prop<RemixBoxEffectsSpec>? containerEffects, List<VariantStyle<IconButtonSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
const
IconButtonStyler.decoration(DecorationMix<Decoration> value)
factory
IconButtonStyler.elevation(ElevationShadow value)
factory
IconButtonStyler.foregroundDecoration(DecorationMix<Decoration> value)
factory
IconButtonStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
IconButtonStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
IconButtonStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
IconButtonStyler.gradient(GradientMix<Gradient> value)
factory
IconButtonStyler.height(double value)
factory
IconButtonStyler.icon(IconStyler value)
factory
IconButtonStyler.image(DecorationImageMix value)
factory
IconButtonStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
IconButtonStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
IconButtonStyler.maxHeight(double value)
factory
IconButtonStyler.maxWidth(double value)
factory
IconButtonStyler.minHeight(double value)
factory
IconButtonStyler.minWidth(double value)
factory
IconButtonStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
IconButtonStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
IconButtonStyler.rotate(double radians, {Alignment alignment = .center})
factory
IconButtonStyler.scale(double scale, {Alignment alignment = .center})
factory
IconButtonStyler.shadow(BoxShadowMix value)
factory
IconButtonStyler.shadows(List<BoxShadowMix> value)
factory
IconButtonStyler.shape(ShapeBorderMix<ShapeBorder> value)
factory
IconButtonStyler.size(double width, double height)
factory
IconButtonStyler.skew(double skewX, double skewY)
factory
IconButtonStyler.spinner(SpinnerStyler value)
factory
IconButtonStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
IconButtonStyler.textStyle(TextStyler value)
factory
IconButtonStyler.transform(Matrix4 value, {Alignment alignment = .center})
factory
IconButtonStyler.translate(double x, double y, [double z = 0.0])
factory
IconButtonStyler.width(double value)
factory

Properties

$animation AnimationConfig?
finalinherited
$container Prop<StyleSpec<BoxSpec>>?
final
$containerEffects Prop<RemixBoxEffectsSpec>?
final
$icon Prop<StyleSpec<IconSpec>>?
final
$modifier WidgetModifierConfig?
finalinherited
$spinner Prop<StyleSpec<SpinnerSpec>>?
final
$stylerFieldNames Set<String>
Names of every field represented by the Styler's Mix.props.
no setteroverride
$variants List<VariantStyle<IconButtonSpec>>?
finalinherited
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
Default implementation uses runtimeType as the merge key
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

alignment(AlignmentGeometry value) IconButtonStyler
animate(AnimationConfig value) IconButtonStyler
Sets the animation configuration.
override
applyVariants(Iterable<NamedVariant> variantsToApply) IconButtonStyler
Applies the specified named variants by merging their styles into this style.
inherited
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) IconButtonStyler
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) IconButtonStyler
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) IconButtonStyler
border(BoxBorderMix<BoxBorder> value) IconButtonStyler
override
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value) IconButtonStyler
override
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) StyleSpec<IconButtonSpec>
Builds the style into a fully resolved spec with metadata.
inherited
call({Key? key, required IconData? icon, required String semanticLabel, RemixIconButtonIconBuilder? iconBuilder, RemixIconButtonLoadingBuilder? loadingBuilder, bool loading = false, bool enabled = true, bool enableFeedback = true, VoidCallback? onPressed, VoidCallback? onLongPress, FocusNode? focusNode, bool autofocus = false, String? semanticHint, bool excludeSemantics = false, MouseCursor mouseCursor = SystemMouseCursors.click}) RemixIconButton
clipBehavior(Clip value) IconButtonStyler
color(Color value) IconButtonStyler
constraints(BoxConstraintsMix value) IconButtonStyler
override
container(BoxStyler value) IconButtonStyler
Sets the container.
containerEffects(RemixBoxEffectsMix value) IconButtonStyler
Sets the containerEffects.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
decoration(DecorationMix<Decoration> value) IconButtonStyler
override
elevation(ElevationShadow value) IconButtonStyler
foregroundDecoration(DecorationMix<Decoration> value) IconButtonStyler
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) IconButtonStyler
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) IconButtonStyler
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) IconButtonStyler
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
gradient(GradientMix<Gradient> value) IconButtonStyler
height(double value) IconButtonStyler
icon(IconStyler value) IconButtonStyler
Sets the icon.
iconBlendMode(BlendMode value) IconButtonStyler
Sets icon blend mode
inherited
iconColor(Color value) IconButtonStyler
Sets icon color
inherited
iconFill(double value) IconButtonStyler
Sets icon fill (useful for Material Icons filled variants)
inherited
iconGrade(double value) IconButtonStyler
Sets icon grade (useful for Material Icons)
inherited
iconOpacity(double value) IconButtonStyler
Sets icon opacity
inherited
iconOpticalSize(double value) IconButtonStyler
Sets icon optical size (useful for Material Icons)
inherited
iconShadow(ShadowMix value) IconButtonStyler
Sets single icon shadow
inherited
iconShadows(List<ShadowMix> value) IconButtonStyler
Sets icon shadows
inherited
iconSize(double value) IconButtonStyler
Sets icon size
inherited
iconTextDirection(TextDirection value) IconButtonStyler
Sets icon text direction
inherited
iconWeight(double value) IconButtonStyler
Sets icon weight (useful for variable icons like Material Symbols)
inherited
image(DecorationImageMix value) IconButtonStyler
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<IconButtonSpec, IconButtonStyler> styleBuilder}) IconButtonStyler
Creates a keyframe animation. It will animate through the given timeline.
inherited
linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) IconButtonStyler
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) IconButtonStyler
override
maxHeight(double value) IconButtonStyler
maxWidth(double value) IconButtonStyler
merge(covariant IconButtonStyler? other) IconButtonStyler
Merges with another IconButtonStyler.
override
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) Style<IconButtonSpec>
Merges all active variants with their nested variants recursively.
inherited
minHeight(double value) IconButtonStyler
minWidth(double value) IconButtonStyler
modifier(WidgetModifierConfig value) IconButtonStyler
Sets the widget modifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(IconButtonStyler style) IconButtonStyler
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, IconButtonStyler style) IconButtonStyler
Creates a variant based on the specified breakpoint.
inherited
onBuilder(IconButtonStyler fn(BuildContext context)) IconButtonStyler
Creates a variant using a builder function that receives the build context.
inherited
onDark(IconButtonStyler style) IconButtonStyler
Creates a variant for dark mode.
inherited
onDesktop(IconButtonStyler style) IconButtonStyler
Creates a variant for desktop breakpoint.
inherited
onDisabled(IconButtonStyler style) IconButtonStyler
Creates a variant for disabled state
inherited
onEnabled(IconButtonStyler style) IconButtonStyler
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(IconButtonStyler style) IconButtonStyler
Creates a variant for focused state.
inherited
onFocusVisible(IconButtonStyler style) IconButtonStyler
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
onFuchsia(IconButtonStyler style) IconButtonStyler
Creates a variant for Fuchsia platform.
inherited
onHovered(IconButtonStyler style) IconButtonStyler
Creates a variant for hover state
inherited
onIos(IconButtonStyler style) IconButtonStyler
Creates a variant for iOS platform.
inherited
onLandscape(IconButtonStyler style) IconButtonStyler
Creates a variant for landscape device orientation.
inherited
onLight(IconButtonStyler style) IconButtonStyler
Creates a variant for light mode.
inherited
onLinux(IconButtonStyler style) IconButtonStyler
Creates a variant for Linux platform.
inherited
onLtr(IconButtonStyler style) IconButtonStyler
Creates a variant for left-to-right text direction.
inherited
onMacos(IconButtonStyler style) IconButtonStyler
Creates a variant for macOS platform.
inherited
onMobile(IconButtonStyler style) IconButtonStyler
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, IconButtonStyler style) IconButtonStyler
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(IconButtonStyler style) IconButtonStyler
Creates a variant for portrait device orientation.
inherited
onPressed(IconButtonStyler style) IconButtonStyler
Creates a variant for pressed state
inherited
onRtl(IconButtonStyler style) IconButtonStyler
Creates a variant for right-to-left text direction.
inherited
onTablet(IconButtonStyler style) IconButtonStyler
Creates a variant for tablet breakpoint.
inherited
onWeb(IconButtonStyler style) IconButtonStyler
Creates a variant for web platform.
inherited
onWindows(IconButtonStyler style) IconButtonStyler
Creates a variant for Windows platform.
inherited
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) IconButtonStyler
override
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required IconButtonStyler styleBuilder(P phase, IconButtonStyler style), required CurveAnimationConfig configBuilder(P phase)}) IconButtonStyler
Creates a phase animation. It will animate through the given phases.
inherited
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) IconButtonStyler
resolve(BuildContext context) StyleSpec<IconButtonSpec>
Resolves to StyleSpec<IconButtonSpec> using context.
override
rotate(double radians, {Alignment alignment = .center}) IconButtonStyler
scale(double scale, {Alignment alignment = .center}) IconButtonStyler
shadow(BoxShadowMix value) IconButtonStyler
shadows(List<BoxShadowMix> value) IconButtonStyler
shape(ShapeBorderMix<ShapeBorder> value) IconButtonStyler
override
size(double width, double height) IconButtonStyler
skew(double skewX, double skewY) IconButtonStyler
spinner(SpinnerStyler value) IconButtonStyler
Sets the spinner.
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) IconButtonStyler
textStyle(TextStyler value) IconButtonStyler
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
transform(Matrix4 value, {Alignment alignment = .center}) IconButtonStyler
override
translate(double x, double y, [double z = 0.0]) IconButtonStyler
variant(Variant variant, IconButtonStyler style) IconButtonStyler
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<IconButtonSpec>> value) IconButtonStyler
Sets the style variants.
override
width(double value) IconButtonStyler
wrap(WidgetModifierConfig value) IconButtonStyler
Wraps with a widget modifier.
override

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited