ProgressStyler class

Inheritance
Mixed-in types
Available extensions

Constructors

ProgressStyler({BoxStyler? container, BoxStyler? track, BoxStyler? indicator, BoxStyler? trackContainer, RemixBoxEffectsMix? trackEffects, RemixBoxEffectsMix? indicatorEffects, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<ProgressSpec>>? variants})
ProgressStyler.alignment(AlignmentGeometry value)
factory
ProgressStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
ProgressStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
ProgressStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
ProgressStyler.border(BoxBorderMix<BoxBorder> value)
factory
ProgressStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
factory
ProgressStyler.clipBehavior(Clip value)
factory
ProgressStyler.color(Color value)
factory
ProgressStyler.constraints(BoxConstraintsMix value)
factory
ProgressStyler.container(BoxStyler value)
factory
ProgressStyler.create({Prop<StyleSpec<BoxSpec>>? container, Prop<StyleSpec<BoxSpec>>? track, Prop<StyleSpec<BoxSpec>>? indicator, Prop<StyleSpec<BoxSpec>>? trackContainer, Prop<RemixBoxEffectsSpec>? trackEffects, Prop<RemixBoxEffectsSpec>? indicatorEffects, List<VariantStyle<ProgressSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
const
ProgressStyler.decoration(DecorationMix<Decoration> value)
factory
ProgressStyler.elevation(ElevationShadow value)
factory
ProgressStyler.foregroundDecoration(DecorationMix<Decoration> value)
factory
ProgressStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
ProgressStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
ProgressStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
ProgressStyler.gradient(GradientMix<Gradient> value)
factory
ProgressStyler.height(double value)
factory
ProgressStyler.image(DecorationImageMix value)
factory
ProgressStyler.indicator(BoxStyler value)
factory
ProgressStyler.indicatorEffects(RemixBoxEffectsMix value)
factory
ProgressStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
ProgressStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
ProgressStyler.maxHeight(double value)
factory
ProgressStyler.maxWidth(double value)
factory
ProgressStyler.minHeight(double value)
factory
ProgressStyler.minWidth(double value)
factory
ProgressStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
ProgressStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
ProgressStyler.rotate(double radians, {Alignment alignment = .center})
factory
ProgressStyler.scale(double scale, {Alignment alignment = .center})
factory
ProgressStyler.shadow(BoxShadowMix value)
factory
ProgressStyler.shadows(List<BoxShadowMix> value)
factory
ProgressStyler.shape(ShapeBorderMix<ShapeBorder> value)
factory
ProgressStyler.size(double width, double height)
factory
ProgressStyler.skew(double skewX, double skewY)
factory
ProgressStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
ProgressStyler.textStyle(TextStyler value)
factory
ProgressStyler.track(BoxStyler value)
factory
ProgressStyler.trackContainer(BoxStyler value)
factory
ProgressStyler.trackEffects(RemixBoxEffectsMix value)
factory
ProgressStyler.transform(Matrix4 value, {Alignment alignment = .center})
factory
ProgressStyler.translate(double x, double y, [double z = 0.0])
factory
ProgressStyler.width(double value)
factory

Properties

$animation AnimationConfig?
finalinherited
$container Prop<StyleSpec<BoxSpec>>?
final
$indicator Prop<StyleSpec<BoxSpec>>?
final
$indicatorEffects Prop<RemixBoxEffectsSpec>?
final
$modifier WidgetModifierConfig?
finalinherited
$track Prop<StyleSpec<BoxSpec>>?
final
$trackContainer Prop<StyleSpec<BoxSpec>>?
final
$trackEffects Prop<RemixBoxEffectsSpec>?
final
$variants List<VariantStyle<ProgressSpec>>?
finalinherited
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
Default implementation uses runtimeType as the merge key
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

alignment(AlignmentGeometry value) ProgressStyler
animate(AnimationConfig value) ProgressStyler
Sets the animation configuration.
override
applyVariants(Iterable<NamedVariant> variantsToApply) ProgressStyler
Applies the specified named variants by merging their styles into this style.
inherited
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) ProgressStyler
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) ProgressStyler
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) ProgressStyler
border(BoxBorderMix<BoxBorder> value) ProgressStyler
override
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value) ProgressStyler
override
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) StyleSpec<ProgressSpec>
Builds the style into a fully resolved spec with metadata.
inherited
call({Key? key, required double value}) RemixProgress

Available on ProgressStyler, provided by the RemixProgressStylerRemixHelpers extension

Creates a RemixProgress widget with this style applied.
clipBehavior(Clip value) ProgressStyler
color(Color value) ProgressStyler
constraints(BoxConstraintsMix value) ProgressStyler
override
container(BoxStyler value) ProgressStyler
Sets the container.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
decoration(DecorationMix<Decoration> value) ProgressStyler
override
elevation(ElevationShadow value) ProgressStyler
foregroundDecoration(DecorationMix<Decoration> value) ProgressStyler
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) ProgressStyler
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) ProgressStyler
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) ProgressStyler
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
gradient(GradientMix<Gradient> value) ProgressStyler
height(double value) ProgressStyler
image(DecorationImageMix value) ProgressStyler
indicator(BoxStyler value) ProgressStyler
Sets the indicator.
indicatorColor(Color value) ProgressStyler

Available on ProgressStyler, provided by the RemixProgressStylerRemixHelpers extension

Sets fill color
indicatorEffects(RemixBoxEffectsMix value) ProgressStyler
Sets the indicatorEffects.
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<ProgressSpec, ProgressStyler> styleBuilder}) ProgressStyler
Creates a keyframe animation. It will animate through the given timeline.
inherited
linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) ProgressStyler
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) ProgressStyler
override
maxHeight(double value) ProgressStyler
maxWidth(double value) ProgressStyler
merge(covariant ProgressStyler? other) ProgressStyler
Merges with another ProgressStyler.
override
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) Style<ProgressSpec>
Merges all active variants with their nested variants recursively.
inherited
minHeight(double value) ProgressStyler
minWidth(double value) ProgressStyler
modifier(WidgetModifierConfig value) ProgressStyler
Sets the widget modifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(ProgressStyler style) ProgressStyler
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, ProgressStyler style) ProgressStyler
Creates a variant based on the specified breakpoint.
inherited
onBuilder(ProgressStyler fn(BuildContext context)) ProgressStyler
Creates a variant using a builder function that receives the build context.
inherited
onDark(ProgressStyler style) ProgressStyler
Creates a variant for dark mode.
inherited
onDesktop(ProgressStyler style) ProgressStyler
Creates a variant for desktop breakpoint.
inherited
onDisabled(ProgressStyler style) ProgressStyler
Creates a variant for disabled state
inherited
onEnabled(ProgressStyler style) ProgressStyler
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(ProgressStyler style) ProgressStyler
Creates a variant for focused state.
inherited
onFocusVisible(ProgressStyler style) ProgressStyler
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
onFuchsia(ProgressStyler style) ProgressStyler
Creates a variant for Fuchsia platform.
inherited
onHovered(ProgressStyler style) ProgressStyler
Creates a variant for hover state
inherited
onIos(ProgressStyler style) ProgressStyler
Creates a variant for iOS platform.
inherited
onLandscape(ProgressStyler style) ProgressStyler
Creates a variant for landscape device orientation.
inherited
onLight(ProgressStyler style) ProgressStyler
Creates a variant for light mode.
inherited
onLinux(ProgressStyler style) ProgressStyler
Creates a variant for Linux platform.
inherited
onLtr(ProgressStyler style) ProgressStyler
Creates a variant for left-to-right text direction.
inherited
onMacos(ProgressStyler style) ProgressStyler
Creates a variant for macOS platform.
inherited
onMobile(ProgressStyler style) ProgressStyler
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, ProgressStyler style) ProgressStyler
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(ProgressStyler style) ProgressStyler
Creates a variant for portrait device orientation.
inherited
onPressed(ProgressStyler style) ProgressStyler
Creates a variant for pressed state
inherited
onRtl(ProgressStyler style) ProgressStyler
Creates a variant for right-to-left text direction.
inherited
onTablet(ProgressStyler style) ProgressStyler
Creates a variant for tablet breakpoint.
inherited
onWeb(ProgressStyler style) ProgressStyler
Creates a variant for web platform.
inherited
onWindows(ProgressStyler style) ProgressStyler
Creates a variant for Windows platform.
inherited
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) ProgressStyler
override
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required ProgressStyler styleBuilder(P phase, ProgressStyler style), required CurveAnimationConfig configBuilder(P phase)}) ProgressStyler
Creates a phase animation. It will animate through the given phases.
inherited
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) ProgressStyler
resolve(BuildContext context) StyleSpec<ProgressSpec>
Resolves to StyleSpec<ProgressSpec> using context.
override
rotate(double radians, {Alignment alignment = .center}) ProgressStyler
scale(double scale, {Alignment alignment = .center}) ProgressStyler
shadow(BoxShadowMix value) ProgressStyler
shadows(List<BoxShadowMix> value) ProgressStyler
shape(ShapeBorderMix<ShapeBorder> value) ProgressStyler
override
size(double width, double height) ProgressStyler
skew(double skewX, double skewY) ProgressStyler
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) ProgressStyler
textStyle(TextStyler value) ProgressStyler
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
track(BoxStyler value) ProgressStyler
Sets the track.
trackColor(Color value) ProgressStyler

Available on ProgressStyler, provided by the RemixProgressStylerRemixHelpers extension

Sets track color
trackContainer(BoxStyler value) ProgressStyler
Sets the trackContainer.
trackEffects(RemixBoxEffectsMix value) ProgressStyler
Sets the trackEffects.
transform(Matrix4 value, {Alignment alignment = .center}) ProgressStyler
override
translate(double x, double y, [double z = 0.0]) ProgressStyler
variant(Variant variant, ProgressStyler style) ProgressStyler
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<ProgressSpec>> value) ProgressStyler
Sets the style variants.
override
width(double value) ProgressStyler
wrap(WidgetModifierConfig value) ProgressStyler
Wraps with a widget modifier.
override

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited