PropSource<V> class
sealed
Represents the origin of a property value.
A PropSource is a sealed class with three concrete implementations:
- ValueSource: Holds a direct value
- TokenSource: References a token to be resolved from context
- MixSource: Contains a Mix value for accumulation merging
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited