RemixSpinner class

An animated loading indicator with Mix styling.

Examples

// Basic spinner
RemixSpinner()

// Custom spinner with track
RemixSpinner(
  style: SpinnerStyler(
    size: 32,
    indicatorColor: Colors.blue,
    trackColor: Colors.blue.withValues(alpha: 0.2),
  ),
)
Inheritance

Constructors

RemixSpinner({Key? key, String? semanticsLabel, String? semanticsValue, SpinnerStyler style = const SpinnerStyler.create(), SpinnerSpec? styleSpec})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The accessible name exposed when this spinner is not decorative.
final
semanticsValue → String?
Optional status text exposed with semanticsLabel.
final
style → SpinnerStyler
The style configuration for the spinner.
final
styleSpec → SpinnerSpec?
Optional raw style spec that bypasses fluent style resolution.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

styleFrom → SpinnerStyler Function({AnimationConfig? animation, Color? color, Duration? duration, Color? indicatorColor, Radius? leafRadius, WidgetModifierConfig? modifier, double? opacity, double? size, double? strokeWidth, Color? trackColor, double? trackStrokeWidth, List<VariantStyle<SpinnerSpec>>? variants})
final