SelectMenuItemSpec class

Resolved visual values for a select menu item.

Implemented types
Annotations
  • @MixableSpec.new(extraStylerMixins: [RemixBoxStylerMixin, IconStyleMixin])

Constructors

SelectMenuItemSpec({StyleSpec<FlexBoxSpec>? container, StyleSpec<TextSpec>? text, StyleSpec<BoxSpec>? indicator, StyleSpec<IconSpec>? icon})
const

Properties

container StyleSpec<FlexBoxSpec>
final
hashCode int
The hash code for this object.
no setterinherited
icon StyleSpec<IconSpec>
final
indicator StyleSpec<BoxSpec>
final
props List<Object?>
The properties based on which equality and hash code are computed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited
text StyleSpec<TextSpec>
final
type Type
no setterinherited

Methods

copyWith({StyleSpec<FlexBoxSpec>? container, StyleSpec<TextSpec>? text, StyleSpec<BoxSpec>? indicator, StyleSpec<IconSpec>? icon}) SelectMenuItemSpec
Creates a copy of this spec with the given fields replaced by the non-null parameter values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
lerp(covariant SelectMenuItemSpec? other, double t) SelectMenuItemSpec
Linearly interpolates with another Spec object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited