SelectMenuItemStyler class

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

SelectMenuItemStyler({FlexBoxStyler? container, TextStyler? text, BoxStyler? indicator, IconStyler? icon, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<SelectMenuItemSpec>>? variants})
SelectMenuItemStyler.alignment(AlignmentGeometry value)
factory
SelectMenuItemStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
SelectMenuItemStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
SelectMenuItemStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
SelectMenuItemStyler.border(BoxBorderMix<BoxBorder> value)
factory
SelectMenuItemStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
factory
SelectMenuItemStyler.clipBehavior(Clip value)
factory
SelectMenuItemStyler.color(Color value)
factory
SelectMenuItemStyler.column()
factory
SelectMenuItemStyler.constraints(BoxConstraintsMix value)
factory
SelectMenuItemStyler.container(FlexBoxStyler value)
factory
SelectMenuItemStyler.create({Prop<StyleSpec<FlexBoxSpec>>? container, Prop<StyleSpec<TextSpec>>? text, Prop<StyleSpec<BoxSpec>>? indicator, Prop<StyleSpec<IconSpec>>? icon, List<VariantStyle<SelectMenuItemSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
const
SelectMenuItemStyler.crossAxisAlignment(CrossAxisAlignment value)
factory
SelectMenuItemStyler.decoration(DecorationMix<Decoration> value)
factory
SelectMenuItemStyler.direction(Axis value)
factory
SelectMenuItemStyler.elevation(ElevationShadow value)
factory
SelectMenuItemStyler.foregroundDecoration(DecorationMix<Decoration> value)
factory
SelectMenuItemStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
SelectMenuItemStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
SelectMenuItemStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
SelectMenuItemStyler.gradient(GradientMix<Gradient> value)
factory
SelectMenuItemStyler.height(double value)
factory
SelectMenuItemStyler.icon(IconStyler value)
factory
SelectMenuItemStyler.image(DecorationImageMix value)
factory
SelectMenuItemStyler.indicator(BoxStyler value)
factory
SelectMenuItemStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
SelectMenuItemStyler.mainAxisAlignment(MainAxisAlignment value)
factory
SelectMenuItemStyler.mainAxisSize(MainAxisSize value)
factory
SelectMenuItemStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
SelectMenuItemStyler.maxHeight(double value)
factory
SelectMenuItemStyler.maxWidth(double value)
factory
SelectMenuItemStyler.minHeight(double value)
factory
SelectMenuItemStyler.minWidth(double value)
factory
SelectMenuItemStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
SelectMenuItemStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
SelectMenuItemStyler.rotate(double radians, {Alignment alignment = .center})
factory
SelectMenuItemStyler.row()
factory
SelectMenuItemStyler.scale(double scale, {Alignment alignment = .center})
factory
SelectMenuItemStyler.shadow(BoxShadowMix value)
factory
SelectMenuItemStyler.shadows(List<BoxShadowMix> value)
factory
SelectMenuItemStyler.shape(ShapeBorderMix<ShapeBorder> value)
factory
SelectMenuItemStyler.size(double width, double height)
factory
SelectMenuItemStyler.skew(double skewX, double skewY)
factory
SelectMenuItemStyler.spacing(double value)
factory
SelectMenuItemStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
SelectMenuItemStyler.text(TextStyler value)
factory
SelectMenuItemStyler.textBaseline(TextBaseline value)
factory
SelectMenuItemStyler.textDirection(TextDirection value)
factory
SelectMenuItemStyler.textStyle(TextStyler value)
factory
SelectMenuItemStyler.transform(Matrix4 value, {Alignment alignment = .center})
factory
SelectMenuItemStyler.translate(double x, double y, [double z = 0.0])
factory
SelectMenuItemStyler.verticalDirection(VerticalDirection value)
factory
SelectMenuItemStyler.width(double value)
factory

Properties

$animation AnimationConfig?
finalinherited
$container Prop<StyleSpec<FlexBoxSpec>>?
final
$icon Prop<StyleSpec<IconSpec>>?
final
$indicator Prop<StyleSpec<BoxSpec>>?
final
$modifier WidgetModifierConfig?
finalinherited
$stylerFieldNames Set<String>
Names of every field represented by the Styler's Mix.props.
no setteroverride
$text Prop<StyleSpec<TextSpec>>?
final
$variants List<VariantStyle<SelectMenuItemSpec>>?
finalinherited
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
Default implementation uses runtimeType as the merge key
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

alignment(AlignmentGeometry value) SelectMenuItemStyler
animate(AnimationConfig value) SelectMenuItemStyler
Sets the animation configuration.
override
applyVariants(Iterable<NamedVariant> variantsToApply) SelectMenuItemStyler
Applies the specified named variants by merging their styles into this style.
inherited
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) SelectMenuItemStyler
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) SelectMenuItemStyler
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) SelectMenuItemStyler
border(BoxBorderMix<BoxBorder> value) SelectMenuItemStyler
override
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value) SelectMenuItemStyler
override
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) StyleSpec<SelectMenuItemSpec>
Builds the style into a fully resolved spec with metadata.
inherited
clipBehavior(Clip value) SelectMenuItemStyler
color(Color value) SelectMenuItemStyler
column() SelectMenuItemStyler
constraints(BoxConstraintsMix value) SelectMenuItemStyler
override
container(FlexBoxStyler value) SelectMenuItemStyler
Sets the container.
crossAxisAlignment(CrossAxisAlignment value) SelectMenuItemStyler
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
decoration(DecorationMix<Decoration> value) SelectMenuItemStyler
override
direction(Axis value) SelectMenuItemStyler
elevation(ElevationShadow value) SelectMenuItemStyler
foregroundDecoration(DecorationMix<Decoration> value) SelectMenuItemStyler
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) SelectMenuItemStyler
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) SelectMenuItemStyler
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) SelectMenuItemStyler
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
gradient(GradientMix<Gradient> value) SelectMenuItemStyler
height(double value) SelectMenuItemStyler
icon(IconStyler value) SelectMenuItemStyler
Sets the icon.
iconBlendMode(BlendMode value) SelectMenuItemStyler
Sets icon blend mode
inherited
iconColor(Color value) SelectMenuItemStyler
Sets icon color
inherited
iconFill(double value) SelectMenuItemStyler
Sets icon fill (useful for Material Icons filled variants)
inherited
iconGrade(double value) SelectMenuItemStyler
Sets icon grade (useful for Material Icons)
inherited
iconOpacity(double value) SelectMenuItemStyler
Sets icon opacity
inherited
iconOpticalSize(double value) SelectMenuItemStyler
Sets icon optical size (useful for Material Icons)
inherited
iconShadow(ShadowMix value) SelectMenuItemStyler
Sets single icon shadow
inherited
iconShadows(List<ShadowMix> value) SelectMenuItemStyler
Sets icon shadows
inherited
iconSize(double value) SelectMenuItemStyler
Sets icon size
inherited
iconTextDirection(TextDirection value) SelectMenuItemStyler
Sets icon text direction
inherited
iconWeight(double value) SelectMenuItemStyler
Sets icon weight (useful for variable icons like Material Symbols)
inherited
image(DecorationImageMix value) SelectMenuItemStyler
indicator(BoxStyler value) SelectMenuItemStyler
Sets the indicator.
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<SelectMenuItemSpec, SelectMenuItemStyler> styleBuilder}) SelectMenuItemStyler
Creates a keyframe animation. It will animate through the given timeline.
inherited
label(TextStyler value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

Sets label styling (delegates to text for consistency with mixin)
labelColor(Color value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelDecoration(TextDecoration value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelDecorationColor(Color value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelFontFamily(String value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelFontSize(double value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelFontStyle(FontStyle value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelFontWeight(FontWeight value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelHeight(double value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelLetterSpacing(double value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelStyle(TextStyleMix value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

labelWordSpacing(double value) SelectMenuItemStyler

Available on SelectMenuItemStyler, provided by the RemixSelectMenuItemStylerRemixHelpers extension

linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) SelectMenuItemStyler
mainAxisAlignment(MainAxisAlignment value) SelectMenuItemStyler
mainAxisSize(MainAxisSize value) SelectMenuItemStyler
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) SelectMenuItemStyler
override
maxHeight(double value) SelectMenuItemStyler
maxWidth(double value) SelectMenuItemStyler
merge(covariant SelectMenuItemStyler? other) SelectMenuItemStyler
Merges with another SelectMenuItemStyler.
override
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) Style<SelectMenuItemSpec>
Merges all active variants with their nested variants recursively.
inherited
minHeight(double value) SelectMenuItemStyler
minWidth(double value) SelectMenuItemStyler
modifier(WidgetModifierConfig value) SelectMenuItemStyler
Sets the widget modifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant based on the specified breakpoint.
inherited
onBuilder(SelectMenuItemStyler fn(BuildContext context)) SelectMenuItemStyler
Creates a variant using a builder function that receives the build context.
inherited
onDark(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for dark mode.
inherited
onDesktop(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for desktop breakpoint.
inherited
onDisabled(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for disabled state
inherited
onEnabled(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for focused state.
inherited
onFocusVisible(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
onFuchsia(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for Fuchsia platform.
inherited
onHovered(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for hover state
inherited
onIos(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for iOS platform.
inherited
onLandscape(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for landscape device orientation.
inherited
onLight(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for light mode.
inherited
onLinux(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for Linux platform.
inherited
onLtr(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for left-to-right text direction.
inherited
onMacos(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for macOS platform.
inherited
onMobile(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for portrait device orientation.
inherited
onPressed(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for pressed state
inherited
onRtl(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for right-to-left text direction.
inherited
onTablet(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for tablet breakpoint.
inherited
onWeb(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for web platform.
inherited
onWindows(SelectMenuItemStyler style) SelectMenuItemStyler
Creates a variant for Windows platform.
inherited
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) SelectMenuItemStyler
override
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required SelectMenuItemStyler styleBuilder(P phase, SelectMenuItemStyler style), required CurveAnimationConfig configBuilder(P phase)}) SelectMenuItemStyler
Creates a phase animation. It will animate through the given phases.
inherited
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) SelectMenuItemStyler
resolve(BuildContext context) StyleSpec<SelectMenuItemSpec>
Resolves to StyleSpec<SelectMenuItemSpec> using context.
override
rotate(double radians, {Alignment alignment = .center}) SelectMenuItemStyler
row() SelectMenuItemStyler
scale(double scale, {Alignment alignment = .center}) SelectMenuItemStyler
shadow(BoxShadowMix value) SelectMenuItemStyler
shadows(List<BoxShadowMix> value) SelectMenuItemStyler
shape(ShapeBorderMix<ShapeBorder> value) SelectMenuItemStyler
override
size(double width, double height) SelectMenuItemStyler
skew(double skewX, double skewY) SelectMenuItemStyler
spacing(double value) SelectMenuItemStyler
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) SelectMenuItemStyler
text(TextStyler value) SelectMenuItemStyler
Sets the text.
textBaseline(TextBaseline value) SelectMenuItemStyler
textDirection(TextDirection value) SelectMenuItemStyler
textStyle(TextStyler value) SelectMenuItemStyler
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
transform(Matrix4 value, {Alignment alignment = .center}) SelectMenuItemStyler
override
translate(double x, double y, [double z = 0.0]) SelectMenuItemStyler
variant(Variant variant, SelectMenuItemStyler style) SelectMenuItemStyler
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<SelectMenuItemSpec>> value) SelectMenuItemStyler
Sets the style variants.
override
verticalDirection(VerticalDirection value) SelectMenuItemStyler
width(double value) SelectMenuItemStyler
wrap(WidgetModifierConfig value) SelectMenuItemStyler
Wraps with a widget modifier.
override

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited