SpinnerStyler class

Inheritance
Implemented types

Constructors

SpinnerStyler({double? size, double? strokeWidth, Color? indicatorColor, Color? trackColor, double? trackStrokeWidth, Color? color, double? opacity, Radius? leafRadius, Duration? duration, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<SpinnerSpec>>? variants})
SpinnerStyler.color(Color value)
factory
SpinnerStyler.create({Prop<double>? size, Prop<double>? strokeWidth, Prop<Color>? indicatorColor, Prop<Color>? trackColor, Prop<double>? trackStrokeWidth, Prop<Color>? color, Prop<double>? opacity, Prop<Radius>? leafRadius, Prop<Duration>? duration, List<VariantStyle<SpinnerSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
const
SpinnerStyler.duration(Duration value)
factory
SpinnerStyler.indicatorColor(Color value)
factory
SpinnerStyler.leafRadius(Radius value)
factory
SpinnerStyler.opacity(double value)
factory
SpinnerStyler.size(double value)
factory
SpinnerStyler.strokeWidth(double value)
factory
SpinnerStyler.trackColor(Color value)
factory
SpinnerStyler.trackStrokeWidth(double value)
factory

Properties

$animation → AnimationConfig?
finalinherited
$color → Prop<Color>?
final
$duration → Prop<Duration>?
final
$indicatorColor → Prop<Color>?
final
$leafRadius → Prop<Radius>?
final
$modifier → WidgetModifierConfig?
finalinherited
$opacity → Prop<double>?
final
$size → Prop<double>?
final
$strokeWidth → Prop<double>?
final
$stylerFieldNames → Set<String>
Names of every field represented by the Styler's Mix.props.
no setteroverride
$trackColor → Prop<Color>?
final
$trackStrokeWidth → Prop<double>?
final
$variants → List<VariantStyle<SpinnerSpec>>?
finalinherited
hashCode → int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey → Object
Default implementation uses runtimeType as the merge key
no setterinherited
props → List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

animate(AnimationConfig value) → SpinnerStyler
Sets the animation configuration.
override
applyVariants(Iterable<NamedVariant> variantsToApply) → SpinnerStyler
Applies the specified named variants by merging their styles into this style.
inherited
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) → StyleSpec<SpinnerSpec>
Builds the style into a fully resolved spec with metadata.
inherited
call({Key? key, String? semanticsLabel, String? semanticsValue}) → RemixSpinner
color(Color value) → SpinnerStyler
Sets the color.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
duration(Duration value) → SpinnerStyler
Sets the duration.
getDiff(Equatable other) → Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
indicatorColor(Color value) → SpinnerStyler
Sets the indicatorColor.
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<SpinnerSpec, SpinnerStyler> styleBuilder}) → SpinnerStyler
Creates a keyframe animation. It will animate through the given timeline.
inherited
leafRadius(Radius value) → SpinnerStyler
Sets the leafRadius.
merge(covariant SpinnerStyler? other) → SpinnerStyler
Merges with another SpinnerStyler.
override
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) → Style<SpinnerSpec>
Merges all active variants with their nested variants recursively.
inherited
modifier(WidgetModifierConfig value) → SpinnerStyler
Sets the widget modifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(SpinnerStyler style) → SpinnerStyler
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, SpinnerStyler style) → SpinnerStyler
Creates a variant based on the specified breakpoint.
inherited
onBuilder(SpinnerStyler fn(BuildContext context)) → SpinnerStyler
Creates a variant using a builder function that receives the build context.
inherited
onDark(SpinnerStyler style) → SpinnerStyler
Creates a variant for dark mode.
inherited
onDesktop(SpinnerStyler style) → SpinnerStyler
Creates a variant for desktop breakpoint.
inherited
onDisabled(SpinnerStyler style) → SpinnerStyler
Creates a variant for disabled state
inherited
onEnabled(SpinnerStyler style) → SpinnerStyler
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(SpinnerStyler style) → SpinnerStyler
Creates a variant for focused state.
inherited
onFocusVisible(SpinnerStyler style) → SpinnerStyler
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
onFuchsia(SpinnerStyler style) → SpinnerStyler
Creates a variant for Fuchsia platform.
inherited
onHovered(SpinnerStyler style) → SpinnerStyler
Creates a variant for hover state
inherited
onIos(SpinnerStyler style) → SpinnerStyler
Creates a variant for iOS platform.
inherited
onLandscape(SpinnerStyler style) → SpinnerStyler
Creates a variant for landscape device orientation.
inherited
onLight(SpinnerStyler style) → SpinnerStyler
Creates a variant for light mode.
inherited
onLinux(SpinnerStyler style) → SpinnerStyler
Creates a variant for Linux platform.
inherited
onLtr(SpinnerStyler style) → SpinnerStyler
Creates a variant for left-to-right text direction.
inherited
onMacos(SpinnerStyler style) → SpinnerStyler
Creates a variant for macOS platform.
inherited
onMobile(SpinnerStyler style) → SpinnerStyler
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, SpinnerStyler style) → SpinnerStyler
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(SpinnerStyler style) → SpinnerStyler
Creates a variant for portrait device orientation.
inherited
onPressed(SpinnerStyler style) → SpinnerStyler
Creates a variant for pressed state
inherited
onRtl(SpinnerStyler style) → SpinnerStyler
Creates a variant for right-to-left text direction.
inherited
onTablet(SpinnerStyler style) → SpinnerStyler
Creates a variant for tablet breakpoint.
inherited
onWeb(SpinnerStyler style) → SpinnerStyler
Creates a variant for web platform.
inherited
onWindows(SpinnerStyler style) → SpinnerStyler
Creates a variant for Windows platform.
inherited
opacity(double value) → SpinnerStyler
Sets the opacity.
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required SpinnerStyler styleBuilder(P phase, SpinnerStyler style), required CurveAnimationConfig configBuilder(P phase)}) → SpinnerStyler
Creates a phase animation. It will animate through the given phases.
inherited
resolve(BuildContext context) → StyleSpec<SpinnerSpec>
Resolves to StyleSpec<SpinnerSpec> using context.
override
size(double value) → SpinnerStyler
Sets the size.
strokeWidth(double value) → SpinnerStyler
Sets the strokeWidth.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
trackColor(Color value) → SpinnerStyler
Sets the trackColor.
trackStrokeWidth(double value) → SpinnerStyler
Sets the trackStrokeWidth.
variant(Variant variant, SpinnerStyler style) → SpinnerStyler
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<SpinnerSpec>> value) → SpinnerStyler
Sets the style variants.
override
wrap(WidgetModifierConfig value) → SpinnerStyler
Wraps with a widget modifier.
override

Operators

operator ==(Object other) → bool
Overrides the equality operator to compare based on the properties.
inherited