StyleBuilder<S extends Spec<S>> class

Builds widgets with Mix styling.

StyleBuilder handles the resolution of Style into a resolved spec and provides it to the builder function. It also manages style inheritance, variant application, and modifier rendering.

Inheritance

Constructors

StyleBuilder({Key? key, required Style<S> style, required Widget builder(BuildContext context, S spec), WidgetStatesController? controller, bool inheritable = false})
const

Properties

builder Widget Function(BuildContext context, S spec)
Function that builds the widget with the resolved style.
final
controller WidgetStatesController?
Optional controller for managing widget state.
final
hashCode int
The hash code for this object.
no setterinherited
inheritable bool
Whether to provide the resolved style to descendant widgets.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style Style<S>
The style element to resolve and apply.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StyleBuilder<S>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited