TabStyler class

Inheritance
Implemented types
Mixed-in types

Constructors

TabStyler({FlexBoxStyler? container, TextStyler? label, IconStyler? icon, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<TabSpec>>? variants})
TabStyler.alignment(AlignmentGeometry value)
factory
TabStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
TabStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
TabStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
TabStyler.border(BoxBorderMix<BoxBorder> value)
factory
TabStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
factory
TabStyler.clipBehavior(Clip value)
factory
TabStyler.color(Color value)
factory
TabStyler.column()
factory
TabStyler.constraints(BoxConstraintsMix value)
factory
TabStyler.container(FlexBoxStyler value)
factory
TabStyler.create({Prop<StyleSpec<FlexBoxSpec>>? container, Prop<StyleSpec<TextSpec>>? label, Prop<StyleSpec<IconSpec>>? icon, List<VariantStyle<TabSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
const
TabStyler.crossAxisAlignment(CrossAxisAlignment value)
factory
TabStyler.decoration(DecorationMix<Decoration> value)
factory
TabStyler.direction(Axis value)
factory
TabStyler.elevation(ElevationShadow value)
factory
TabStyler.foregroundDecoration(DecorationMix<Decoration> value)
factory
TabStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
TabStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
TabStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
TabStyler.gradient(GradientMix<Gradient> value)
factory
TabStyler.height(double value)
factory
TabStyler.icon(IconStyler value)
factory
TabStyler.image(DecorationImageMix value)
factory
TabStyler.label(TextStyler value)
factory
TabStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
TabStyler.mainAxisAlignment(MainAxisAlignment value)
factory
TabStyler.mainAxisSize(MainAxisSize value)
factory
TabStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
TabStyler.maxHeight(double value)
factory
TabStyler.maxWidth(double value)
factory
TabStyler.minHeight(double value)
factory
TabStyler.minWidth(double value)
factory
TabStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
TabStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
TabStyler.rotate(double radians, {Alignment alignment = .center})
factory
TabStyler.row()
factory
TabStyler.scale(double scale, {Alignment alignment = .center})
factory
TabStyler.shadow(BoxShadowMix value)
factory
TabStyler.shadows(List<BoxShadowMix> value)
factory
TabStyler.shape(ShapeBorderMix<ShapeBorder> value)
factory
TabStyler.size(double width, double height)
factory
TabStyler.skew(double skewX, double skewY)
factory
TabStyler.spacing(double value)
factory
TabStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
TabStyler.textBaseline(TextBaseline value)
factory
TabStyler.textDirection(TextDirection value)
factory
TabStyler.textStyle(TextStyler value)
factory
TabStyler.transform(Matrix4 value, {Alignment alignment = .center})
factory
TabStyler.translate(double x, double y, [double z = 0.0])
factory
TabStyler.verticalDirection(VerticalDirection value)
factory
TabStyler.width(double value)
factory

Properties

$animation AnimationConfig?
finalinherited
$container Prop<StyleSpec<FlexBoxSpec>>?
final
$icon Prop<StyleSpec<IconSpec>>?
final
$label Prop<StyleSpec<TextSpec>>?
final
$modifier WidgetModifierConfig?
finalinherited
$stylerFieldNames Set<String>
Names of every field represented by the Styler's Mix.props.
no setteroverride
$variants List<VariantStyle<TabSpec>>?
finalinherited
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
Default implementation uses runtimeType as the merge key
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

alignment(AlignmentGeometry value) TabStyler
animate(AnimationConfig value) TabStyler
Sets the animation configuration.
override
applyVariants(Iterable<NamedVariant> variantsToApply) TabStyler
Applies the specified named variants by merging their styles into this style.
inherited
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) TabStyler
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) TabStyler
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) TabStyler
border(BoxBorderMix<BoxBorder> value) TabStyler
override
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value) TabStyler
override
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) StyleSpec<TabSpec>
Builds the style into a fully resolved spec with metadata.
inherited
call({Key? key, required String tabId, Widget? child, String? label, IconData? icon, bool enabled = true, MouseCursor mouseCursor = SystemMouseCursors.click, bool enableFeedback = true, FocusNode? focusNode, bool autofocus = false, ValueChanged<bool>? onFocusChange, ValueChanged<bool>? onHoverChange, ValueChanged<bool>? onPressChange, ValueWidgetBuilder<NakedTabState>? builder, String? semanticLabel}) RemixTab
clipBehavior(Clip value) TabStyler
color(Color value) TabStyler
column() TabStyler
constraints(BoxConstraintsMix value) TabStyler
override
container(FlexBoxStyler value) TabStyler
Sets the container.
crossAxisAlignment(CrossAxisAlignment value) TabStyler
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
decoration(DecorationMix<Decoration> value) TabStyler
override
direction(Axis value) TabStyler
elevation(ElevationShadow value) TabStyler
foregroundDecoration(DecorationMix<Decoration> value) TabStyler
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) TabStyler
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) TabStyler
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) TabStyler
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
gradient(GradientMix<Gradient> value) TabStyler
height(double value) TabStyler
icon(IconStyler value) TabStyler
Sets the icon.
iconBlendMode(BlendMode value) TabStyler
Sets icon blend mode
inherited
iconColor(Color value) TabStyler
Sets icon color
inherited
iconFill(double value) TabStyler
Sets icon fill (useful for Material Icons filled variants)
inherited
iconGrade(double value) TabStyler
Sets icon grade (useful for Material Icons)
inherited
iconOpacity(double value) TabStyler
Sets icon opacity
inherited
iconOpticalSize(double value) TabStyler
Sets icon optical size (useful for Material Icons)
inherited
iconShadow(ShadowMix value) TabStyler
Sets single icon shadow
inherited
iconShadows(List<ShadowMix> value) TabStyler
Sets icon shadows
inherited
iconSize(double value) TabStyler
Sets icon size
inherited
iconTextDirection(TextDirection value) TabStyler
Sets icon text direction
inherited
iconWeight(double value) TabStyler
Sets icon weight (useful for variable icons like Material Symbols)
inherited
image(DecorationImageMix value) TabStyler
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<TabSpec, TabStyler> styleBuilder}) TabStyler
Creates a keyframe animation. It will animate through the given timeline.
inherited
label(TextStyler value) TabStyler
Sets the label.
labelColor(Color value) TabStyler
Sets label/text color
inherited
labelDecoration(TextDecoration value) TabStyler
Sets label/text decoration (underline, strikethrough, etc.)
inherited
labelDecorationColor(Color value) TabStyler
Sets label/text decoration color
inherited
labelFontFamily(String value) TabStyler
Sets label/text font family
inherited
labelFontSize(double value) TabStyler
Sets label/text font size
inherited
labelFontStyle(FontStyle value) TabStyler
Sets label/text font style (italic/normal)
inherited
labelFontWeight(FontWeight value) TabStyler
Sets label/text font weight
inherited
labelHeight(double value) TabStyler
Sets label/text line height
inherited
labelLetterSpacing(double value) TabStyler
Sets label/text letter spacing
inherited
labelStyle(TextStyleMix value) TabStyler
Sets label/text style using TextStyleMix directly
inherited
labelWordSpacing(double value) TabStyler
Sets label/text word spacing
inherited
linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) TabStyler
mainAxisAlignment(MainAxisAlignment value) TabStyler
mainAxisSize(MainAxisSize value) TabStyler
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) TabStyler
override
maxHeight(double value) TabStyler
maxWidth(double value) TabStyler
merge(covariant TabStyler? other) TabStyler
Merges with another TabStyler.
override
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) Style<TabSpec>
Merges all active variants with their nested variants recursively.
inherited
minHeight(double value) TabStyler
minWidth(double value) TabStyler
modifier(WidgetModifierConfig value) TabStyler
Sets the widget modifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(TabStyler style) TabStyler
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, TabStyler style) TabStyler
Creates a variant based on the specified breakpoint.
inherited
onBuilder(TabStyler fn(BuildContext context)) TabStyler
Creates a variant using a builder function that receives the build context.
inherited
onDark(TabStyler style) TabStyler
Creates a variant for dark mode.
inherited
onDesktop(TabStyler style) TabStyler
Creates a variant for desktop breakpoint.
inherited
onDisabled(TabStyler style) TabStyler
Creates a variant for disabled state
inherited
onEnabled(TabStyler style) TabStyler
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(TabStyler style) TabStyler
Creates a variant for focused state.
inherited
onFocusVisible(TabStyler style) TabStyler
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
onFuchsia(TabStyler style) TabStyler
Creates a variant for Fuchsia platform.
inherited
onHovered(TabStyler style) TabStyler
Creates a variant for hover state
inherited
onIos(TabStyler style) TabStyler
Creates a variant for iOS platform.
inherited
onLandscape(TabStyler style) TabStyler
Creates a variant for landscape device orientation.
inherited
onLight(TabStyler style) TabStyler
Creates a variant for light mode.
inherited
onLinux(TabStyler style) TabStyler
Creates a variant for Linux platform.
inherited
onLtr(TabStyler style) TabStyler
Creates a variant for left-to-right text direction.
inherited
onMacos(TabStyler style) TabStyler
Creates a variant for macOS platform.
inherited
onMobile(TabStyler style) TabStyler
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, TabStyler style) TabStyler
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(TabStyler style) TabStyler
Creates a variant for portrait device orientation.
inherited
onPressed(TabStyler style) TabStyler
Creates a variant for pressed state
inherited
onRtl(TabStyler style) TabStyler
Creates a variant for right-to-left text direction.
inherited
onTablet(TabStyler style) TabStyler
Creates a variant for tablet breakpoint.
inherited
onWeb(TabStyler style) TabStyler
Creates a variant for web platform.
inherited
onWindows(TabStyler style) TabStyler
Creates a variant for Windows platform.
inherited
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) TabStyler
override
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required TabStyler styleBuilder(P phase, TabStyler style), required CurveAnimationConfig configBuilder(P phase)}) TabStyler
Creates a phase animation. It will animate through the given phases.
inherited
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) TabStyler
resolve(BuildContext context) StyleSpec<TabSpec>
Resolves to StyleSpec<TabSpec> using context.
override
rotate(double radians, {Alignment alignment = .center}) TabStyler
row() TabStyler
scale(double scale, {Alignment alignment = .center}) TabStyler
shadow(BoxShadowMix value) TabStyler
shadows(List<BoxShadowMix> value) TabStyler
shape(ShapeBorderMix<ShapeBorder> value) TabStyler
override
size(double width, double height) TabStyler
skew(double skewX, double skewY) TabStyler
spacing(double value) TabStyler
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) TabStyler
textBaseline(TextBaseline value) TabStyler
textDirection(TextDirection value) TabStyler
textStyle(TextStyler value) TabStyler
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
transform(Matrix4 value, {Alignment alignment = .center}) TabStyler
override
translate(double x, double y, [double z = 0.0]) TabStyler
variant(Variant variant, TabStyler style) TabStyler
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<TabSpec>> value) TabStyler
Sets the style variants.
override
verticalDirection(VerticalDirection value) TabStyler
width(double value) TabStyler
wrap(WidgetModifierConfig value) TabStyler
Wraps with a widget modifier.
override

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited