ToggleGroupItemStyler class

Inheritance
Implemented types
Mixed-in types

Constructors

ToggleGroupItemStyler({FlexBoxStyler? container, TextStyler? label, IconStyler? icon, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<ToggleGroupItemSpec>>? variants})
ToggleGroupItemStyler.alignment(AlignmentGeometry value)
factory
ToggleGroupItemStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
ToggleGroupItemStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
ToggleGroupItemStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
ToggleGroupItemStyler.border(BoxBorderMix<BoxBorder> value)
factory
ToggleGroupItemStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
factory
ToggleGroupItemStyler.clipBehavior(Clip value)
factory
ToggleGroupItemStyler.color(Color value)
factory
ToggleGroupItemStyler.column()
factory
ToggleGroupItemStyler.constraints(BoxConstraintsMix value)
factory
ToggleGroupItemStyler.container(FlexBoxStyler value)
factory
ToggleGroupItemStyler.create({Prop<StyleSpec<FlexBoxSpec>>? container, Prop<StyleSpec<TextSpec>>? label, Prop<StyleSpec<IconSpec>>? icon, List<VariantStyle<ToggleGroupItemSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
const
ToggleGroupItemStyler.crossAxisAlignment(CrossAxisAlignment value)
factory
ToggleGroupItemStyler.decoration(DecorationMix<Decoration> value)
factory
ToggleGroupItemStyler.direction(Axis value)
factory
ToggleGroupItemStyler.elevation(ElevationShadow value)
factory
ToggleGroupItemStyler.foregroundDecoration(DecorationMix<Decoration> value)
factory
ToggleGroupItemStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
ToggleGroupItemStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
ToggleGroupItemStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
ToggleGroupItemStyler.gradient(GradientMix<Gradient> value)
factory
ToggleGroupItemStyler.height(double value)
factory
ToggleGroupItemStyler.icon(IconStyler value)
factory
ToggleGroupItemStyler.image(DecorationImageMix value)
factory
ToggleGroupItemStyler.label(TextStyler value)
factory
ToggleGroupItemStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
ToggleGroupItemStyler.mainAxisAlignment(MainAxisAlignment value)
factory
ToggleGroupItemStyler.mainAxisSize(MainAxisSize value)
factory
ToggleGroupItemStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
ToggleGroupItemStyler.maxHeight(double value)
factory
ToggleGroupItemStyler.maxWidth(double value)
factory
ToggleGroupItemStyler.minHeight(double value)
factory
ToggleGroupItemStyler.minWidth(double value)
factory
ToggleGroupItemStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
ToggleGroupItemStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
ToggleGroupItemStyler.rotate(double radians, {Alignment alignment = .center})
factory
ToggleGroupItemStyler.row()
factory
ToggleGroupItemStyler.scale(double scale, {Alignment alignment = .center})
factory
ToggleGroupItemStyler.shadow(BoxShadowMix value)
factory
ToggleGroupItemStyler.shadows(List<BoxShadowMix> value)
factory
ToggleGroupItemStyler.shape(ShapeBorderMix<ShapeBorder> value)
factory
ToggleGroupItemStyler.size(double width, double height)
factory
ToggleGroupItemStyler.skew(double skewX, double skewY)
factory
ToggleGroupItemStyler.spacing(double value)
factory
ToggleGroupItemStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
ToggleGroupItemStyler.textBaseline(TextBaseline value)
factory
ToggleGroupItemStyler.textDirection(TextDirection value)
factory
ToggleGroupItemStyler.textStyle(TextStyler value)
factory
ToggleGroupItemStyler.transform(Matrix4 value, {Alignment alignment = .center})
factory
ToggleGroupItemStyler.translate(double x, double y, [double z = 0.0])
factory
ToggleGroupItemStyler.verticalDirection(VerticalDirection value)
factory
ToggleGroupItemStyler.width(double value)
factory

Properties

$animation → AnimationConfig?
finalinherited
$container → Prop<StyleSpec<FlexBoxSpec>>?
final
$icon → Prop<StyleSpec<IconSpec>>?
final
$label → Prop<StyleSpec<TextSpec>>?
final
$modifier → WidgetModifierConfig?
finalinherited
$stylerFieldNames → Set<String>
Names of every field represented by the Styler's Mix.props.
no setteroverride
$variants → List<VariantStyle<ToggleGroupItemSpec>>?
finalinherited
hashCode → int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey → Object
Default implementation uses runtimeType as the merge key
no setterinherited
props → List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

alignment(AlignmentGeometry value) → ToggleGroupItemStyler
animate(AnimationConfig value) → ToggleGroupItemStyler
Sets the animation configuration.
override
applyVariants(Iterable<NamedVariant> variantsToApply) → ToggleGroupItemStyler
Applies the specified named variants by merging their styles into this style.
inherited
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) → ToggleGroupItemStyler
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) → ToggleGroupItemStyler
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) → ToggleGroupItemStyler
border(BoxBorderMix<BoxBorder> value) → ToggleGroupItemStyler
override
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value) → ToggleGroupItemStyler
override
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) → StyleSpec<ToggleGroupItemSpec>
Builds the style into a fully resolved spec with metadata.
inherited
clipBehavior(Clip value) → ToggleGroupItemStyler
color(Color value) → ToggleGroupItemStyler
column() → ToggleGroupItemStyler
constraints(BoxConstraintsMix value) → ToggleGroupItemStyler
override
container(FlexBoxStyler value) → ToggleGroupItemStyler
Sets the container.
crossAxisAlignment(CrossAxisAlignment value) → ToggleGroupItemStyler
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
decoration(DecorationMix<Decoration> value) → ToggleGroupItemStyler
override
direction(Axis value) → ToggleGroupItemStyler
elevation(ElevationShadow value) → ToggleGroupItemStyler
foregroundDecoration(DecorationMix<Decoration> value) → ToggleGroupItemStyler
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) → ToggleGroupItemStyler
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) → ToggleGroupItemStyler
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) → ToggleGroupItemStyler
getDiff(Equatable other) → Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
gradient(GradientMix<Gradient> value) → ToggleGroupItemStyler
height(double value) → ToggleGroupItemStyler
icon(IconStyler value) → ToggleGroupItemStyler
Sets the icon.
iconBlendMode(BlendMode value) → ToggleGroupItemStyler
Sets icon blend mode
inherited
iconColor(Color value) → ToggleGroupItemStyler
Sets icon color
inherited
iconFill(double value) → ToggleGroupItemStyler
Sets icon fill (useful for Material Icons filled variants)
inherited
iconGrade(double value) → ToggleGroupItemStyler
Sets icon grade (useful for Material Icons)
inherited
iconOpacity(double value) → ToggleGroupItemStyler
Sets icon opacity
inherited
iconOpticalSize(double value) → ToggleGroupItemStyler
Sets icon optical size (useful for Material Icons)
inherited
iconShadow(ShadowMix value) → ToggleGroupItemStyler
Sets single icon shadow
inherited
iconShadows(List<ShadowMix> value) → ToggleGroupItemStyler
Sets icon shadows
inherited
iconSize(double value) → ToggleGroupItemStyler
Sets icon size
inherited
iconTextDirection(TextDirection value) → ToggleGroupItemStyler
Sets icon text direction
inherited
iconWeight(double value) → ToggleGroupItemStyler
Sets icon weight (useful for variable icons like Material Symbols)
inherited
image(DecorationImageMix value) → ToggleGroupItemStyler
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<ToggleGroupItemSpec, ToggleGroupItemStyler> styleBuilder}) → ToggleGroupItemStyler
Creates a keyframe animation. It will animate through the given timeline.
inherited
label(TextStyler value) → ToggleGroupItemStyler
Sets the label.
labelColor(Color value) → ToggleGroupItemStyler
Sets label/text color
inherited
labelDecoration(TextDecoration value) → ToggleGroupItemStyler
Sets label/text decoration (underline, strikethrough, etc.)
inherited
labelDecorationColor(Color value) → ToggleGroupItemStyler
Sets label/text decoration color
inherited
labelFontFamily(String value) → ToggleGroupItemStyler
Sets label/text font family
inherited
labelFontSize(double value) → ToggleGroupItemStyler
Sets label/text font size
inherited
labelFontStyle(FontStyle value) → ToggleGroupItemStyler
Sets label/text font style (italic/normal)
inherited
labelFontWeight(FontWeight value) → ToggleGroupItemStyler
Sets label/text font weight
inherited
labelHeight(double value) → ToggleGroupItemStyler
Sets label/text line height
inherited
labelLetterSpacing(double value) → ToggleGroupItemStyler
Sets label/text letter spacing
inherited
labelStyle(TextStyleMix value) → ToggleGroupItemStyler
Sets label/text style using TextStyleMix directly
inherited
labelWordSpacing(double value) → ToggleGroupItemStyler
Sets label/text word spacing
inherited
linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) → ToggleGroupItemStyler
mainAxisAlignment(MainAxisAlignment value) → ToggleGroupItemStyler
mainAxisSize(MainAxisSize value) → ToggleGroupItemStyler
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) → ToggleGroupItemStyler
override
maxHeight(double value) → ToggleGroupItemStyler
maxWidth(double value) → ToggleGroupItemStyler
merge(covariant ToggleGroupItemStyler? other) → ToggleGroupItemStyler
Merges with another ToggleGroupItemStyler.
override
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) → Style<ToggleGroupItemSpec>
Merges all active variants with their nested variants recursively.
inherited
minHeight(double value) → ToggleGroupItemStyler
minWidth(double value) → ToggleGroupItemStyler
modifier(WidgetModifierConfig value) → ToggleGroupItemStyler
Sets the widget modifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant based on the specified breakpoint.
inherited
onBuilder(ToggleGroupItemStyler fn(BuildContext context)) → ToggleGroupItemStyler
Creates a variant using a builder function that receives the build context.
inherited
onDark(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for dark mode.
inherited
onDesktop(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for desktop breakpoint.
inherited
onDisabled(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for disabled state
inherited
onEnabled(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for focused state.
inherited
onFocusVisible(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
onFuchsia(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for Fuchsia platform.
inherited
onHovered(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for hover state
inherited
onIos(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for iOS platform.
inherited
onLandscape(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for landscape device orientation.
inherited
onLight(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for light mode.
inherited
onLinux(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for Linux platform.
inherited
onLtr(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for left-to-right text direction.
inherited
onMacos(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for macOS platform.
inherited
onMobile(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for portrait device orientation.
inherited
onPressed(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for pressed state
inherited
onRtl(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for right-to-left text direction.
inherited
onTablet(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for tablet breakpoint.
inherited
onWeb(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for web platform.
inherited
onWindows(ToggleGroupItemStyler style) → ToggleGroupItemStyler
Creates a variant for Windows platform.
inherited
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) → ToggleGroupItemStyler
override
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required ToggleGroupItemStyler styleBuilder(P phase, ToggleGroupItemStyler style), required CurveAnimationConfig configBuilder(P phase)}) → ToggleGroupItemStyler
Creates a phase animation. It will animate through the given phases.
inherited
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) → ToggleGroupItemStyler
resolve(BuildContext context) → StyleSpec<ToggleGroupItemSpec>
Resolves to StyleSpec<ToggleGroupItemSpec> using context.
override
rotate(double radians, {Alignment alignment = .center}) → ToggleGroupItemStyler
row() → ToggleGroupItemStyler
scale(double scale, {Alignment alignment = .center}) → ToggleGroupItemStyler
shadow(BoxShadowMix value) → ToggleGroupItemStyler
shadows(List<BoxShadowMix> value) → ToggleGroupItemStyler
shape(ShapeBorderMix<ShapeBorder> value) → ToggleGroupItemStyler
override
size(double width, double height) → ToggleGroupItemStyler
skew(double skewX, double skewY) → ToggleGroupItemStyler
spacing(double value) → ToggleGroupItemStyler
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) → ToggleGroupItemStyler
textBaseline(TextBaseline value) → ToggleGroupItemStyler
textDirection(TextDirection value) → ToggleGroupItemStyler
textStyle(TextStyler value) → ToggleGroupItemStyler
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
transform(Matrix4 value, {Alignment alignment = .center}) → ToggleGroupItemStyler
override
translate(double x, double y, [double z = 0.0]) → ToggleGroupItemStyler
variant(Variant variant, ToggleGroupItemStyler style) → ToggleGroupItemStyler
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<ToggleGroupItemSpec>> value) → ToggleGroupItemStyler
Sets the style variants.
override
verticalDirection(VerticalDirection value) → ToggleGroupItemStyler
width(double value) → ToggleGroupItemStyler
wrap(WidgetModifierConfig value) → ToggleGroupItemStyler
Wraps with a widget modifier.
override

Operators

operator ==(Object other) → bool
Overrides the equality operator to compare based on the properties.
inherited