spinner property
Styling specification for the button's loading spinner.
Defines the appearance of the spinner shown during asynchronous operations when the button is in loading state.
Implementation
@override
final StyleSpec<SpinnerSpec> spinner;
Styling specification for the button's loading spinner.
Defines the appearance of the spinner shown during asynchronous operations when the button is in loading state.
@override
final StyleSpec<SpinnerSpec> spinner;