DialogSpec class
Resolved visual properties for a RemixDialog.
- Implemented types
- Annotations
-
- @MixableSpec.new(target: RemixDialog.new, extraStylerMixins: [RemixBoxStylerMixin])
Constructors
-
DialogSpec({StyleSpec<
BoxSpec> ? container, RemixBoxEffectsSpec? containerEffects, StyleSpec<TextSpec> ? title, StyleSpec<TextSpec> ? description, StyleSpec<FlexBoxSpec> ? actions}) -
const
Properties
-
actions
→ StyleSpec<
FlexBoxSpec> -
final
-
container
→ StyleSpec<
BoxSpec> -
final
- containerEffects → RemixBoxEffectsSpec?
-
final
-
description
→ StyleSpec<
TextSpec> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
-
title
→ StyleSpec<
TextSpec> -
final
- type → Type
-
no setterinherited
Methods
-
copyWith(
{StyleSpec< BoxSpec> ? container, RemixBoxEffectsSpec? containerEffects, StyleSpec<TextSpec> ? title, StyleSpec<TextSpec> ? description, StyleSpec<FlexBoxSpec> ? actions}) → DialogSpec -
Creates a copy of this spec with the given fields
replaced by the non-null parameter values.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
lerp(
covariant DialogSpec? other, double t) → DialogSpec - Linearly interpolates with another Spec object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited