DialogStyler class
- Inheritance
-
- Implemented types
-
- Mixed-in types
-
Constructors
-
DialogStyler({BoxStyler? container, RemixBoxEffectsMix? containerEffects, TextStyler? title, TextStyler? description, FlexBoxStyler? actions, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<DialogSpec>>? variants})
-
-
DialogStyler.actions(FlexBoxStyler value)
-
factory
-
DialogStyler.alignment(AlignmentGeometry value)
-
factory
-
DialogStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
-
DialogStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
-
DialogStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
-
DialogStyler.border(BoxBorderMix<BoxBorder> value)
-
factory
-
DialogStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
-
factory
-
DialogStyler.clipBehavior(Clip value)
-
factory
-
DialogStyler.color(Color value)
-
factory
-
DialogStyler.constraints(BoxConstraintsMix value)
-
factory
-
DialogStyler.container(BoxStyler value)
-
factory
-
DialogStyler.containerEffects(RemixBoxEffectsMix value)
-
factory
-
DialogStyler.create({Prop<StyleSpec<BoxSpec>>? container, Prop<RemixBoxEffectsSpec>? containerEffects, Prop<StyleSpec<TextSpec>>? title, Prop<StyleSpec<TextSpec>>? description, Prop<StyleSpec<FlexBoxSpec>>? actions, List<VariantStyle<DialogSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
-
const
-
DialogStyler.decoration(DecorationMix<Decoration> value)
-
factory
-
DialogStyler.description(TextStyler value)
-
factory
-
DialogStyler.elevation(ElevationShadow value)
-
factory
-
DialogStyler.foregroundDecoration(DecorationMix<Decoration> value)
-
factory
-
DialogStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
-
factory
-
DialogStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
-
factory
-
DialogStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
-
factory
-
DialogStyler.gradient(GradientMix<Gradient> value)
-
factory
-
DialogStyler.height(double value)
-
factory
-
DialogStyler.image(DecorationImageMix value)
-
factory
-
DialogStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
-
factory
-
DialogStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
-
factory
-
DialogStyler.maxHeight(double value)
-
factory
-
DialogStyler.maxWidth(double value)
-
factory
-
DialogStyler.minHeight(double value)
-
factory
-
DialogStyler.minWidth(double value)
-
factory
-
DialogStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
-
factory
-
DialogStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
-
factory
-
DialogStyler.rotate(double radians, {Alignment alignment = .center})
-
factory
-
DialogStyler.scale(double scale, {Alignment alignment = .center})
-
factory
-
DialogStyler.shadow(BoxShadowMix value)
-
factory
-
DialogStyler.shadows(List<BoxShadowMix> value)
-
factory
-
DialogStyler.shape(ShapeBorderMix<ShapeBorder> value)
-
factory
-
DialogStyler.size(double width, double height)
-
factory
-
DialogStyler.skew(double skewX, double skewY)
-
factory
-
DialogStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
-
factory
-
DialogStyler.textStyle(TextStyler value)
-
factory
-
DialogStyler.title(TextStyler value)
-
factory
-
DialogStyler.transform(Matrix4 value, {Alignment alignment = .center})
-
factory
-
DialogStyler.translate(double x, double y, [double z = 0.0])
-
factory
-
DialogStyler.width(double value)
-
factory
Methods
-
actions(FlexBoxStyler value)
→ DialogStyler
-
Sets the actions.
-
alignment(AlignmentGeometry value)
→ DialogStyler
-
-
animate(AnimationConfig value)
→ DialogStyler
-
Sets the animation configuration.
override
-
applyVariants(Iterable<NamedVariant> variantsToApply)
→ DialogStyler
-
Applies the specified named variants by merging their styles into this style.
inherited
-
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
→ DialogStyler
-
-
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
→ DialogStyler
-
-
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
→ DialogStyler
-
-
border(BoxBorderMix<BoxBorder> value)
→ DialogStyler
-
override
-
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
→ DialogStyler
-
override
-
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}})
→ StyleSpec<DialogSpec>
-
Builds the style into a fully resolved spec with metadata.
inherited
-
call({Key? key, Widget? child, String? title, String? description, List<Widget>? actions, bool scrollable = false, bool modal = true, String? semanticLabel})
→ RemixDialog
-
-
clipBehavior(Clip value)
→ DialogStyler
-
-
color(Color value)
→ DialogStyler
-
-
constraints(BoxConstraintsMix value)
→ DialogStyler
-
override
-
container(BoxStyler value)
→ DialogStyler
-
Sets the container.
-
containerEffects(RemixBoxEffectsMix value)
→ DialogStyler
-
Sets the containerEffects.
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
override
-
decoration(DecorationMix<Decoration> value)
→ DialogStyler
-
override
-
description(TextStyler value)
→ DialogStyler
-
Sets the description.
-
elevation(ElevationShadow value)
→ DialogStyler
-
-
foregroundDecoration(DecorationMix<Decoration> value)
→ DialogStyler
-
-
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
→ DialogStyler
-
-
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
→ DialogStyler
-
-
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
→ DialogStyler
-
-
getDiff(Equatable other)
→ Map<String, String>
-
Returns a map of properties that differ between this object and another.
inherited
-
gradient(GradientMix<Gradient> value)
→ DialogStyler
-
-
height(double value)
→ DialogStyler
-
-
image(DecorationImageMix value)
→ DialogStyler
-
-
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<DialogSpec, DialogStyler> styleBuilder})
→ DialogStyler
-
Creates a keyframe animation. It will animate through the given timeline.
inherited
-
linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
→ DialogStyler
-
-
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
→ DialogStyler
-
override
-
maxHeight(double value)
→ DialogStyler
-
-
maxWidth(double value)
→ DialogStyler
-
-
merge(covariant DialogStyler? other)
→ DialogStyler
-
Merges with another DialogStyler.
override
-
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants})
→ Style<DialogSpec>
-
Merges all active variants with their nested variants recursively.
inherited
-
minHeight(double value)
→ DialogStyler
-
-
minWidth(double value)
→ DialogStyler
-
-
modifier(WidgetModifierConfig value)
→ DialogStyler
-
Sets the widget modifier.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onAndroid(DialogStyler style)
→ DialogStyler
-
Creates a variant for Android platform.
inherited
-
onBreakpoint(Breakpoint breakpoint, DialogStyler style)
→ DialogStyler
-
Creates a variant based on the specified breakpoint.
inherited
-
onBuilder(DialogStyler fn(BuildContext context))
→ DialogStyler
-
Creates a variant using a builder function that receives the build context.
inherited
-
onDark(DialogStyler style)
→ DialogStyler
-
Creates a variant for dark mode.
inherited
-
onDesktop(DialogStyler style)
→ DialogStyler
-
Creates a variant for desktop breakpoint.
inherited
-
onDisabled(DialogStyler style)
→ DialogStyler
-
Creates a variant for disabled state
inherited
-
onEnabled(DialogStyler style)
→ DialogStyler
-
Creates a variant for enabled state (opposite of disabled)
inherited
-
onFocused(DialogStyler style)
→ DialogStyler
-
Creates a variant for focused state.
inherited
-
onFocusVisible(DialogStyler style)
→ DialogStyler
-
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
-
onFuchsia(DialogStyler style)
→ DialogStyler
-
Creates a variant for Fuchsia platform.
inherited
-
onHovered(DialogStyler style)
→ DialogStyler
-
Creates a variant for hover state
inherited
-
onIos(DialogStyler style)
→ DialogStyler
-
Creates a variant for iOS platform.
inherited
-
onLandscape(DialogStyler style)
→ DialogStyler
-
Creates a variant for landscape device orientation.
inherited
-
onLight(DialogStyler style)
→ DialogStyler
-
Creates a variant for light mode.
inherited
-
onLinux(DialogStyler style)
→ DialogStyler
-
Creates a variant for Linux platform.
inherited
-
onLtr(DialogStyler style)
→ DialogStyler
-
Creates a variant for left-to-right text direction.
inherited
-
onMacos(DialogStyler style)
→ DialogStyler
-
Creates a variant for macOS platform.
inherited
-
onMobile(DialogStyler style)
→ DialogStyler
-
Creates a variant for mobile breakpoint.
inherited
-
onNot(ContextVariant contextVariant, DialogStyler style)
→ DialogStyler
-
Creates a variant for when the context does NOT match the provided variant.
inherited
-
onPortrait(DialogStyler style)
→ DialogStyler
-
Creates a variant for portrait device orientation.
inherited
-
onPressed(DialogStyler style)
→ DialogStyler
-
Creates a variant for pressed state
inherited
-
onRtl(DialogStyler style)
→ DialogStyler
-
Creates a variant for right-to-left text direction.
inherited
-
onTablet(DialogStyler style)
→ DialogStyler
-
Creates a variant for tablet breakpoint.
inherited
-
onWeb(DialogStyler style)
→ DialogStyler
-
Creates a variant for web platform.
inherited
-
onWindows(DialogStyler style)
→ DialogStyler
-
Creates a variant for Windows platform.
inherited
-
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
→ DialogStyler
-
override
-
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required DialogStyler styleBuilder(P phase, DialogStyler style), required CurveAnimationConfig configBuilder(P phase)})
→ DialogStyler
-
Creates a phase animation. It will animate through the given phases.
inherited
-
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
→ DialogStyler
-
-
resolve(BuildContext context)
→ StyleSpec<DialogSpec>
-
Resolves to StyleSpec<DialogSpec> using
context.
override
-
rotate(double radians, {Alignment alignment = .center})
→ DialogStyler
-
-
scale(double scale, {Alignment alignment = .center})
→ DialogStyler
-
-
shadow(BoxShadowMix value)
→ DialogStyler
-
-
shadows(List<BoxShadowMix> value)
→ DialogStyler
-
-
shape(ShapeBorderMix<ShapeBorder> value)
→ DialogStyler
-
override
-
size(double width, double height)
→ DialogStyler
-
-
skew(double skewX, double skewY)
→ DialogStyler
-
-
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
→ DialogStyler
-
-
textStyle(TextStyler value)
→ DialogStyler
-
-
title(TextStyler value)
→ DialogStyler
-
Sets the title.
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
transform(Matrix4 value, {Alignment alignment = .center})
→ DialogStyler
-
override
-
translate(double x, double y, [double z = 0.0])
→ DialogStyler
-
-
variant(Variant variant, DialogStyler style)
→ DialogStyler
-
Must be implemented by the class using this mixin
inherited
-
variants(List<VariantStyle<DialogSpec>> value)
→ DialogStyler
-
Sets the style variants.
override
-
width(double value)
→ DialogStyler
-
-
wrap(WidgetModifierConfig value)
→ DialogStyler
-
Wraps with a widget modifier.
override
Operators
-
operator ==(Object other)
→ bool
-
Overrides the equality operator to compare based on the properties.
inherited