RadioStyler class
- Inheritance
- Implemented types
- Mixed-in types
- Available extensions
Constructors
-
RadioStyler({BoxStyler? container, BoxStyler? indicator, RemixBoxEffectsMix? containerEffects, AnimationConfig? animation, WidgetModifierConfig? modifier, List<
VariantStyle< ? variants})RadioSpec> > - RadioStyler.alignment(AlignmentGeometry value)
-
factory
-
RadioStyler.backgroundImage(ImageProvider<
Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) -
factory
- RadioStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
- RadioStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
-
RadioStyler.border(BoxBorderMix<
BoxBorder> value) -
factory
-
RadioStyler.borderRadius(BorderRadiusGeometryMix<
BorderRadiusGeometry> value) -
factory
- RadioStyler.clipBehavior(Clip value)
-
factory
- RadioStyler.color(Color value)
-
factory
- RadioStyler.constraints(BoxConstraintsMix value)
-
factory
- RadioStyler.container(BoxStyler value)
-
factory
- RadioStyler.containerEffects(RemixBoxEffectsMix value)
-
factory
-
RadioStyler.create({Prop<
StyleSpec< ? container, Prop<BoxSpec> >StyleSpec< ? indicator, Prop<BoxSpec> >RemixBoxEffectsSpec> ? containerEffects, List<VariantStyle< ? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})RadioSpec> > -
const
-
RadioStyler.decoration(DecorationMix<
Decoration> value) -
factory
- RadioStyler.elevation(ElevationShadow value)
-
factory
-
RadioStyler.foregroundDecoration(DecorationMix<
Decoration> value) -
factory
-
RadioStyler.foregroundLinearGradient({required List<
Color> colors, List<double> ? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) -
factory
-
RadioStyler.foregroundRadialGradient({required List<
Color> colors, List<double> ? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) -
factory
-
RadioStyler.foregroundSweepGradient({required List<
Color> colors, List<double> ? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) -
factory
-
RadioStyler.gradient(GradientMix<
Gradient> value) -
factory
- RadioStyler.height(double value)
-
factory
- RadioStyler.image(DecorationImageMix value)
-
factory
- RadioStyler.indicator(BoxStyler value)
-
factory
-
RadioStyler.linearGradient({required List<
Color> colors, List<double> ? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) -
factory
-
RadioStyler.margin(EdgeInsetsGeometryMix<
EdgeInsetsGeometry> value) -
factory
- RadioStyler.maxHeight(double value)
-
factory
- RadioStyler.maxWidth(double value)
-
factory
- RadioStyler.minHeight(double value)
-
factory
- RadioStyler.minWidth(double value)
-
factory
-
RadioStyler.padding(EdgeInsetsGeometryMix<
EdgeInsetsGeometry> value) -
factory
-
RadioStyler.radialGradient({required List<
Color> colors, List<double> ? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) -
factory
- RadioStyler.rotate(double radians, {Alignment alignment = .center})
-
factory
- RadioStyler.scale(double scale, {Alignment alignment = .center})
-
factory
- RadioStyler.shadow(BoxShadowMix value)
-
factory
-
RadioStyler.shadows(List<
BoxShadowMix> value) -
factory
-
RadioStyler.shape(ShapeBorderMix<
ShapeBorder> value) -
factory
- RadioStyler.size(double width, double height)
-
factory
- RadioStyler.skew(double skewX, double skewY)
-
factory
-
RadioStyler.sweepGradient({required List<
Color> colors, List<double> ? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) -
factory
- RadioStyler.textStyle(TextStyler value)
-
factory
- RadioStyler.transform(Matrix4 value, {Alignment alignment = .center})
-
factory
- RadioStyler.translate(double x, double y, [double z = 0.0])
-
factory
- RadioStyler.width(double value)
-
factory
Properties
- $animation → AnimationConfig?
-
finalinherited
-
$container
→ Prop<
StyleSpec< ?BoxSpec> > -
final
-
$containerEffects
→ Prop<
RemixBoxEffectsSpec> ? -
final
-
$indicator
→ Prop<
StyleSpec< ?BoxSpec> > -
final
- $modifier → WidgetModifierConfig?
-
finalinherited
-
$stylerFieldNames
→ Set<
String> -
Names of every field represented by the Styler's Mix.props.
no setteroverride
-
$variants
→ List<
VariantStyle< ?RadioSpec> > -
finalinherited
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
- mergeKey → Object
-
Default implementation uses runtimeType as the merge key
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
Methods
-
alignment(
AlignmentGeometry value) → RadioStyler -
animate(
AnimationConfig value) → RadioStyler -
Sets the animation configuration.
override
-
applyVariants(
Iterable< NamedVariant> variantsToApply) → RadioStyler -
Applies the specified named variants by merging their styles into this style.
inherited
-
backgroundImage(
ImageProvider< Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) → RadioStyler -
backgroundImageAsset(
String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) → RadioStyler -
backgroundImageUrl(
String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) → RadioStyler -
border(
BoxBorderMix< BoxBorder> value) → RadioStyler -
override
-
borderRadius(
BorderRadiusGeometryMix< BorderRadiusGeometry> value) → RadioStyler -
override
-
build(
BuildContext context, {Set< NamedVariant> namedVariants = const {}}) → StyleSpec<RadioSpec> -
Builds the style into a fully resolved spec with metadata.
inherited
-
call<
T> ({Key? key, required T value, required String semanticLabel, bool enabled = true, bool toggleable = false, MouseCursor? mouseCursor, FocusNode? focusNode, bool autofocus = false, bool excludeSemantics = false}) → RemixRadio< T> -
clipBehavior(
Clip value) → RadioStyler -
color(
Color value) → RadioStyler -
constraints(
BoxConstraintsMix value) → RadioStyler -
override
-
container(
BoxStyler value) → RadioStyler - Sets the container.
-
containerEffects(
RemixBoxEffectsMix value) → RadioStyler - Sets the containerEffects.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
decoration(
DecorationMix< Decoration> value) → RadioStyler -
override
-
elevation(
ElevationShadow value) → RadioStyler -
fillColor(
Color value) → RadioStyler -
Available on RadioStyler, provided by the RemixRadioStylerRemixHelpers extension
Sets fill color on the container. -
foregroundDecoration(
DecorationMix< Decoration> value) → RadioStyler -
foregroundLinearGradient(
{required List< Color> colors, List<double> ? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) → RadioStyler -
foregroundRadialGradient(
{required List< Color> colors, List<double> ? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) → RadioStyler -
foregroundSweepGradient(
{required List< Color> colors, List<double> ? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) → RadioStyler -
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
gradient(
GradientMix< Gradient> value) → RadioStyler -
height(
double value) → RadioStyler -
image(
DecorationImageMix value) → RadioStyler -
indicator(
BoxStyler value) → RadioStyler - Sets the indicator.
-
indicatorColor(
Color value) → RadioStyler -
Available on RadioStyler, provided by the RemixRadioStylerRemixHelpers extension
Sets the indicator's fill color. -
keyframeAnimation(
{Listenable? trigger, required List< KeyframeTrack> timeline, required KeyframeStyleBuilder<RadioSpec, RadioStyler> styleBuilder}) → RadioStyler -
Creates a keyframe animation. It will animate through the given timeline.
inherited
-
linearGradient(
{required List< Color> colors, List<double> ? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) → RadioStyler -
margin(
EdgeInsetsGeometryMix< EdgeInsetsGeometry> value) → RadioStyler -
override
-
maxHeight(
double value) → RadioStyler -
maxWidth(
double value) → RadioStyler -
merge(
covariant RadioStyler? other) → RadioStyler -
Merges with another RadioStyler.
override
-
mergeActiveVariants(
BuildContext context, {required Set< NamedVariant> namedVariants}) → Style<RadioSpec> -
Merges all active variants with their nested variants recursively.
inherited
-
minHeight(
double value) → RadioStyler -
minWidth(
double value) → RadioStyler -
modifier(
WidgetModifierConfig value) → RadioStyler - Sets the widget modifier.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAndroid(
RadioStyler style) → RadioStyler -
Creates a variant for Android platform.
inherited
-
onBreakpoint(
Breakpoint breakpoint, RadioStyler style) → RadioStyler -
Creates a variant based on the specified breakpoint.
inherited
-
onBuilder(
RadioStyler fn(BuildContext context)) → RadioStyler -
Creates a variant using a builder function that receives the build context.
inherited
-
onDark(
RadioStyler style) → RadioStyler -
Creates a variant for dark mode.
inherited
-
onDesktop(
RadioStyler style) → RadioStyler -
Creates a variant for desktop breakpoint.
inherited
-
onDisabled(
RadioStyler style) → RadioStyler -
Creates a variant for disabled state
inherited
-
onEnabled(
RadioStyler style) → RadioStyler -
Creates a variant for enabled state (opposite of disabled)
inherited
-
onFocused(
RadioStyler style) → RadioStyler -
Creates a variant for focused state.
inherited
-
onFocusVisible(
RadioStyler style) → RadioStyler -
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
-
onFuchsia(
RadioStyler style) → RadioStyler -
Creates a variant for Fuchsia platform.
inherited
-
onHovered(
RadioStyler style) → RadioStyler -
Creates a variant for hover state
inherited
-
onIos(
RadioStyler style) → RadioStyler -
Creates a variant for iOS platform.
inherited
-
onLandscape(
RadioStyler style) → RadioStyler -
Creates a variant for landscape device orientation.
inherited
-
onLight(
RadioStyler style) → RadioStyler -
Creates a variant for light mode.
inherited
-
onLinux(
RadioStyler style) → RadioStyler -
Creates a variant for Linux platform.
inherited
-
onLtr(
RadioStyler style) → RadioStyler -
Creates a variant for left-to-right text direction.
inherited
-
onMacos(
RadioStyler style) → RadioStyler -
Creates a variant for macOS platform.
inherited
-
onMobile(
RadioStyler style) → RadioStyler -
Creates a variant for mobile breakpoint.
inherited
-
onNot(
ContextVariant contextVariant, RadioStyler style) → RadioStyler -
Creates a variant for when the context does NOT match the provided variant.
inherited
-
onPortrait(
RadioStyler style) → RadioStyler -
Creates a variant for portrait device orientation.
inherited
-
onPressed(
RadioStyler style) → RadioStyler -
Creates a variant for pressed state
inherited
-
onRtl(
RadioStyler style) → RadioStyler -
Creates a variant for right-to-left text direction.
inherited
-
onTablet(
RadioStyler style) → RadioStyler -
Creates a variant for tablet breakpoint.
inherited
-
onWeb(
RadioStyler style) → RadioStyler -
Creates a variant for web platform.
inherited
-
onWindows(
RadioStyler style) → RadioStyler -
Creates a variant for Windows platform.
inherited
-
padding(
EdgeInsetsGeometryMix< EdgeInsetsGeometry> value) → RadioStyler -
override
-
phaseAnimation<
P> ({Listenable? trigger, required List< P> phases, required RadioStyler styleBuilder(P phase, RadioStyler style), required CurveAnimationConfig configBuilder(P phase)}) → RadioStyler -
Creates a phase animation. It will animate through the given phases.
inherited
-
radialGradient(
{required List< Color> colors, List<double> ? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) → RadioStyler -
resolve(
BuildContext context) → StyleSpec< RadioSpec> -
Resolves to StyleSpec<RadioSpec> using
context.override -
rotate(
double radians, {Alignment alignment = .center}) → RadioStyler -
scale(
double scale, {Alignment alignment = .center}) → RadioStyler -
shadow(
BoxShadowMix value) → RadioStyler -
shadows(
List< BoxShadowMix> value) → RadioStyler -
shape(
ShapeBorderMix< ShapeBorder> value) → RadioStyler -
override
-
size(
double width, double height) → RadioStyler -
skew(
double skewX, double skewY) → RadioStyler -
sweepGradient(
{required List< Color> colors, List<double> ? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) → RadioStyler -
textStyle(
TextStyler value) → RadioStyler -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
transform(
Matrix4 value, {Alignment alignment = .center}) → RadioStyler -
override
-
translate(
double x, double y, [double z = 0.0]) → RadioStyler -
variant(
Variant variant, RadioStyler style) → RadioStyler -
Must be implemented by the class using this mixin
inherited
-
variants(
List< VariantStyle< value) → RadioStylerRadioSpec> > -
Sets the style variants.
override
-
width(
double value) → RadioStyler -
wrap(
WidgetModifierConfig value) → RadioStyler -
Wraps with a widget modifier.
override
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited