RemixBoxEffectsMix class
Mix representation of RemixBoxEffectsSpec.
- Inheritance
-
- Object
- Mixable<
RemixBoxEffectsSpec> - Mix<
RemixBoxEffectsSpec> - RemixBoxEffectsMix
- Annotations
Constructors
- RemixBoxEffectsMix({RemixBoxEffectLayerMix? behindContent, RemixBoxEffectLayerMix? overContent, double? backdropBlur, BorderSideMix? outline, double? outlineOffset})
- RemixBoxEffectsMix.backdropBlur(double value)
-
Blurs whatever is painted behind the box.
factory
- RemixBoxEffectsMix.behindContent(RemixBoxEffectLayerMix value)
-
Shadow and fill layers painted beneath the box's content.
factory
-
RemixBoxEffectsMix.create({Prop<
RemixBoxEffectLayerSpec> ? behindContent, Prop<RemixBoxEffectLayerSpec> ? overContent, Prop<double> ? backdropBlur, Prop<BorderSide> ? outline, Prop<double> ? outlineOffset}) -
const
- RemixBoxEffectsMix.outline(BorderSideMix value)
-
Paints an outline outside the box's own border.
factory
- RemixBoxEffectsMix.outlineOffset(double value)
-
Distance between the box edge and its outline.
factory
- RemixBoxEffectsMix.overContent(RemixBoxEffectLayerMix value)
-
Shadow and fill layers painted over the box's content.
factory
Properties
-
$backdropBlur
→ Prop<
double> ? -
final
-
$behindContent
→ Prop<
RemixBoxEffectLayerSpec> ? -
final
-
$outline
→ Prop<
BorderSide> ? -
final
-
$outlineOffset
→ Prop<
double> ? -
final
-
$overContent
→ Prop<
RemixBoxEffectLayerSpec> ? -
final
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
- mergeKey → Object
-
The key used to identify compatible types for merging.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
Methods
-
backdropBlur(
double value) → RemixBoxEffectsMix - Chainable counterpart of RemixBoxEffectsMix.backdropBlur.
-
behindContent(
RemixBoxEffectLayerMix value) → RemixBoxEffectsMix - Chainable counterpart of RemixBoxEffectsMix.behindContent.
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
merge(
covariant RemixBoxEffectsMix? other) → RemixBoxEffectsMix -
Merges this instance with
other, withothertaking precedence.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
outline(
BorderSideMix value) → RemixBoxEffectsMix - Chainable counterpart of RemixBoxEffectsMix.outline.
-
outlineOffset(
double value) → RemixBoxEffectsMix - Chainable counterpart of RemixBoxEffectsMix.outlineOffset.
-
overContent(
RemixBoxEffectLayerMix value) → RemixBoxEffectsMix - Chainable counterpart of RemixBoxEffectsMix.overContent.
-
resolve(
BuildContext context) → RemixBoxEffectsSpec -
Resolves this to a concrete value using the provided
context.override -
toString(
) → String -
Overrides string representation for debugging and logging.
inherited
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited