SelectStyler class
- Inheritance
-
- Implemented types
-
- Mixed-in types
-
Constructors
-
SelectStyler({SelectTriggerStyler? trigger, SelectContentStyler? content, SelectMenuItemStyler? item, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<SelectSpec>>? variants})
-
-
SelectStyler.alignment(AlignmentGeometry value)
-
factory
-
SelectStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
-
SelectStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
-
SelectStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
-
factory
-
SelectStyler.border(BoxBorderMix<BoxBorder> value)
-
factory
-
SelectStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
-
factory
-
SelectStyler.clipBehavior(Clip value)
-
factory
-
SelectStyler.color(Color value)
-
factory
-
SelectStyler.constraints(BoxConstraintsMix value)
-
factory
-
SelectStyler.content(SelectContentStyler value)
-
factory
-
SelectStyler.create({Prop<StyleSpec<SelectTriggerSpec>>? trigger, Prop<StyleSpec<SelectContentSpec>>? content, Prop<StyleSpec<SelectMenuItemSpec>>? item, List<VariantStyle<SelectSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
-
const
-
SelectStyler.decoration(DecorationMix<Decoration> value)
-
factory
-
SelectStyler.elevation(ElevationShadow value)
-
factory
-
SelectStyler.foregroundDecoration(DecorationMix<Decoration> value)
-
factory
-
SelectStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
-
factory
-
SelectStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
-
factory
-
SelectStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
-
factory
-
SelectStyler.gradient(GradientMix<Gradient> value)
-
factory
-
SelectStyler.height(double value)
-
factory
-
SelectStyler.image(DecorationImageMix value)
-
factory
-
SelectStyler.item(SelectMenuItemStyler value)
-
factory
-
SelectStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
-
factory
-
SelectStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
-
factory
-
SelectStyler.maxHeight(double value)
-
factory
-
SelectStyler.maxWidth(double value)
-
factory
-
factory
-
SelectStyler.minHeight(double value)
-
factory
-
SelectStyler.minWidth(double value)
-
factory
-
SelectStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
-
factory
-
SelectStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
-
factory
-
SelectStyler.rotate(double radians, {Alignment alignment = .center})
-
factory
-
SelectStyler.scale(double scale, {Alignment alignment = .center})
-
factory
-
SelectStyler.shadow(BoxShadowMix value)
-
factory
-
SelectStyler.shadows(List<BoxShadowMix> value)
-
factory
-
SelectStyler.shape(ShapeBorderMix<ShapeBorder> value)
-
factory
-
SelectStyler.size(double width, double height)
-
factory
-
SelectStyler.skew(double skewX, double skewY)
-
factory
-
SelectStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
-
factory
-
SelectStyler.textStyle(TextStyler value)
-
factory
-
SelectStyler.transform(Matrix4 value, {Alignment alignment = .center})
-
factory
-
SelectStyler.translate(double x, double y, [double z = 0.0])
-
factory
-
SelectStyler.trigger(SelectTriggerStyler value)
-
factory
-
SelectStyler.width(double value)
-
factory
Methods
-
alignment(AlignmentGeometry value)
→ SelectStyler
-
-
animate(AnimationConfig value)
→ SelectStyler
-
Sets the animation configuration.
override
-
applyVariants(Iterable<NamedVariant> variantsToApply)
→ SelectStyler
-
Applies the specified named variants by merging their styles into this style.
inherited
-
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
→ SelectStyler
-
-
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
→ SelectStyler
-
-
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
→ SelectStyler
-
-
border(BoxBorderMix<BoxBorder> value)
→ SelectStyler
-
override
-
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
→ SelectStyler
-
override
-
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}})
→ StyleSpec<SelectSpec>
-
Builds the style into a fully resolved spec with metadata.
inherited
-
call<T>({Key? key, required RemixSelectTrigger trigger, required List<RemixSelectItem<T>> items, T? selectedValue, OverlayPositionConfig positioning = const OverlayPositionConfig(side: .bottom, alignment: .center), ValueChanged<T?>? onChanged, VoidCallback? onOpen, VoidCallback? onClose, bool enabled = true, MouseCursor mouseCursor = SystemMouseCursors.click, String? semanticLabel, bool closeOnSelect = true, FocusNode? focusNode})
→ RemixSelect<T>
-
-
clipBehavior(Clip value)
→ SelectStyler
-
-
color(Color value)
→ SelectStyler
-
-
constraints(BoxConstraintsMix value)
→ SelectStyler
-
override
-
content(SelectContentStyler value)
→ SelectStyler
-
Sets the content.
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
override
-
decoration(DecorationMix<Decoration> value)
→ SelectStyler
-
override
-
elevation(ElevationShadow value)
→ SelectStyler
-
-
foregroundDecoration(DecorationMix<Decoration> value)
→ SelectStyler
-
-
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
→ SelectStyler
-
-
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
→ SelectStyler
-
-
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
→ SelectStyler
-
-
getDiff(Equatable other)
→ Map<String, String>
-
Returns a map of properties that differ between this object and another.
inherited
-
gradient(GradientMix<Gradient> value)
→ SelectStyler
-
-
height(double value)
→ SelectStyler
-
-
image(DecorationImageMix value)
→ SelectStyler
-
-
item(SelectMenuItemStyler value)
→ SelectStyler
-
Sets the item.
-
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<SelectSpec, SelectStyler> styleBuilder})
→ SelectStyler
-
Creates a keyframe animation. It will animate through the given timeline.
inherited
-
linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
→ SelectStyler
-
-
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
→ SelectStyler
-
override
-
maxHeight(double value)
→ SelectStyler
-
-
maxWidth(double value)
→ SelectStyler
-
-
Sets the menuContainer.
-
merge(covariant SelectStyler? other)
→ SelectStyler
-
Merges with another SelectStyler.
override
-
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants})
→ Style<SelectSpec>
-
Merges all active variants with their nested variants recursively.
inherited
-
minHeight(double value)
→ SelectStyler
-
-
minWidth(double value)
→ SelectStyler
-
-
modifier(WidgetModifierConfig value)
→ SelectStyler
-
Sets the widget modifier.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onAndroid(SelectStyler style)
→ SelectStyler
-
Creates a variant for Android platform.
inherited
-
onBreakpoint(Breakpoint breakpoint, SelectStyler style)
→ SelectStyler
-
Creates a variant based on the specified breakpoint.
inherited
-
onBuilder(SelectStyler fn(BuildContext context))
→ SelectStyler
-
Creates a variant using a builder function that receives the build context.
inherited
-
onDark(SelectStyler style)
→ SelectStyler
-
Creates a variant for dark mode.
inherited
-
onDesktop(SelectStyler style)
→ SelectStyler
-
Creates a variant for desktop breakpoint.
inherited
-
onDisabled(SelectStyler style)
→ SelectStyler
-
Creates a variant for disabled state
inherited
-
onEnabled(SelectStyler style)
→ SelectStyler
-
Creates a variant for enabled state (opposite of disabled)
inherited
-
onFocused(SelectStyler style)
→ SelectStyler
-
Creates a variant for focused state.
inherited
-
onFocusVisible(SelectStyler style)
→ SelectStyler
-
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
-
onFuchsia(SelectStyler style)
→ SelectStyler
-
Creates a variant for Fuchsia platform.
inherited
-
onHovered(SelectStyler style)
→ SelectStyler
-
Creates a variant for hover state
inherited
-
onIos(SelectStyler style)
→ SelectStyler
-
Creates a variant for iOS platform.
inherited
-
onLandscape(SelectStyler style)
→ SelectStyler
-
Creates a variant for landscape device orientation.
inherited
-
onLight(SelectStyler style)
→ SelectStyler
-
Creates a variant for light mode.
inherited
-
onLinux(SelectStyler style)
→ SelectStyler
-
Creates a variant for Linux platform.
inherited
-
onLtr(SelectStyler style)
→ SelectStyler
-
Creates a variant for left-to-right text direction.
inherited
-
onMacos(SelectStyler style)
→ SelectStyler
-
Creates a variant for macOS platform.
inherited
-
onMobile(SelectStyler style)
→ SelectStyler
-
Creates a variant for mobile breakpoint.
inherited
-
onNot(ContextVariant contextVariant, SelectStyler style)
→ SelectStyler
-
Creates a variant for when the context does NOT match the provided variant.
inherited
-
onPortrait(SelectStyler style)
→ SelectStyler
-
Creates a variant for portrait device orientation.
inherited
-
onPressed(SelectStyler style)
→ SelectStyler
-
Creates a variant for pressed state
inherited
-
onRtl(SelectStyler style)
→ SelectStyler
-
Creates a variant for right-to-left text direction.
inherited
-
onTablet(SelectStyler style)
→ SelectStyler
-
Creates a variant for tablet breakpoint.
inherited
-
onWeb(SelectStyler style)
→ SelectStyler
-
Creates a variant for web platform.
inherited
-
onWindows(SelectStyler style)
→ SelectStyler
-
Creates a variant for Windows platform.
inherited
-
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
→ SelectStyler
-
override
-
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required SelectStyler styleBuilder(P phase, SelectStyler style), required CurveAnimationConfig configBuilder(P phase)})
→ SelectStyler
-
Creates a phase animation. It will animate through the given phases.
inherited
-
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
→ SelectStyler
-
-
resolve(BuildContext context)
→ StyleSpec<SelectSpec>
-
Resolves to StyleSpec<SelectSpec> using
context.
override
-
rotate(double radians, {Alignment alignment = .center})
→ SelectStyler
-
-
scale(double scale, {Alignment alignment = .center})
→ SelectStyler
-
-
shadow(BoxShadowMix value)
→ SelectStyler
-
-
shadows(List<BoxShadowMix> value)
→ SelectStyler
-
-
shape(ShapeBorderMix<ShapeBorder> value)
→ SelectStyler
-
override
-
size(double width, double height)
→ SelectStyler
-
-
skew(double skewX, double skewY)
→ SelectStyler
-
-
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
→ SelectStyler
-
-
textStyle(TextStyler value)
→ SelectStyler
-
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringShort()
→ String
-
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
transform(Matrix4 value, {Alignment alignment = .center})
→ SelectStyler
-
override
-
translate(double x, double y, [double z = 0.0])
→ SelectStyler
-
-
trigger(SelectTriggerStyler value)
→ SelectStyler
-
Sets the trigger.
-
variant(Variant variant, SelectStyler style)
→ SelectStyler
-
Must be implemented by the class using this mixin
inherited
-
variants(List<VariantStyle<SelectSpec>> value)
→ SelectStyler
-
Sets the style variants.
override
-
width(double value)
→ SelectStyler
-
-
wrap(WidgetModifierConfig value)
→ SelectStyler
-
Wraps with a widget modifier.
override
Operators
-
operator ==(Object other)
→ bool
-
Overrides the equality operator to compare based on the properties.
inherited