TextFieldStyler class

Inheritance
Mixed-in types
Available extensions

Constructors

TextFieldStyler({TextStyler? text, TextStyler? hintText, TextAlign? textAlign, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, EdgeInsets? scrollPadding, Brightness? keyboardAppearance, bool? cursorOpacityAnimates, BoxStyler? container, double? spacing, CrossAxisAlignment? crossAxisAlignment, FlexBoxStyler? layout, TextStyler? helperText, TextStyler? label, RemixBoxEffectsMix? containerEffects, AnimationConfig? animation, WidgetModifierConfig? modifier, List<VariantStyle<TextFieldSpec>>? variants})
TextFieldStyler.alignment(AlignmentGeometry value)
factory
TextFieldStyler.backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
TextFieldStyler.backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
TextFieldStyler.backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat})
factory
TextFieldStyler.border(BoxBorderMix<BoxBorder> value)
factory
TextFieldStyler.borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value)
factory
TextFieldStyler.clipBehavior(Clip value)
factory
TextFieldStyler.color(Color value)
factory
TextFieldStyler.constraints(BoxConstraintsMix value)
factory
TextFieldStyler.container(BoxStyler value)
factory
TextFieldStyler.containerEffects(RemixBoxEffectsMix value)
factory
TextFieldStyler.create({Prop<StyleSpec<TextSpec>>? text, Prop<StyleSpec<TextSpec>>? hintText, Prop<TextAlign>? textAlign, Prop<double>? cursorWidth, Prop<double>? cursorHeight, Prop<Radius>? cursorRadius, Prop<Color>? cursorColor, Prop<BoxHeightStyle>? selectionHeightStyle, Prop<BoxWidthStyle>? selectionWidthStyle, Prop<EdgeInsets>? scrollPadding, Prop<Brightness>? keyboardAppearance, Prop<bool>? cursorOpacityAnimates, Prop<StyleSpec<BoxSpec>>? container, Prop<double>? spacing, Prop<CrossAxisAlignment>? crossAxisAlignment, Prop<StyleSpec<FlexBoxSpec>>? layout, Prop<StyleSpec<TextSpec>>? helperText, Prop<StyleSpec<TextSpec>>? label, Prop<RemixBoxEffectsSpec>? containerEffects, List<VariantStyle<TextFieldSpec>>? variants, WidgetModifierConfig? modifier, AnimationConfig? animation})
const
TextFieldStyler.crossAxisAlignment(CrossAxisAlignment value)
factory
TextFieldStyler.cursorColor(Color value)
factory
TextFieldStyler.cursorHeight(double value)
factory
TextFieldStyler.cursorOpacityAnimates(bool value)
factory
TextFieldStyler.cursorRadius(Radius value)
factory
TextFieldStyler.cursorWidth(double value)
factory
TextFieldStyler.decoration(DecorationMix<Decoration> value)
factory
TextFieldStyler.elevation(ElevationShadow value)
factory
TextFieldStyler.foregroundDecoration(DecorationMix<Decoration> value)
factory
TextFieldStyler.foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
TextFieldStyler.foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
TextFieldStyler.foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
TextFieldStyler.gradient(GradientMix<Gradient> value)
factory
TextFieldStyler.height(double value)
factory
TextFieldStyler.helperText(TextStyler value)
factory
TextFieldStyler.hintText(TextStyler value)
factory
TextFieldStyler.image(DecorationImageMix value)
factory
TextFieldStyler.keyboardAppearance(Brightness value)
factory
TextFieldStyler.label(TextStyler value)
factory
TextFieldStyler.layout(FlexBoxStyler value)
factory
TextFieldStyler.linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode})
factory
TextFieldStyler.margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
TextFieldStyler.maxHeight(double value)
factory
TextFieldStyler.maxWidth(double value)
factory
TextFieldStyler.minHeight(double value)
factory
TextFieldStyler.minWidth(double value)
factory
TextFieldStyler.padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value)
factory
TextFieldStyler.radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode})
factory
TextFieldStyler.rotate(double radians, {Alignment alignment = .center})
factory
TextFieldStyler.scale(double scale, {Alignment alignment = .center})
factory
TextFieldStyler.scrollPadding(EdgeInsets value)
factory
TextFieldStyler.selectionHeightStyle(BoxHeightStyle value)
factory
TextFieldStyler.selectionWidthStyle(BoxWidthStyle value)
factory
TextFieldStyler.shadow(BoxShadowMix value)
factory
TextFieldStyler.shadows(List<BoxShadowMix> value)
factory
TextFieldStyler.shape(ShapeBorderMix<ShapeBorder> value)
factory
TextFieldStyler.size(double width, double height)
factory
TextFieldStyler.skew(double skewX, double skewY)
factory
TextFieldStyler.spacing(double value)
factory
TextFieldStyler.sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode})
factory
TextFieldStyler.text(TextStyler value)
factory
TextFieldStyler.textAlign(TextAlign value)
factory
TextFieldStyler.textStyle(TextStyler value)
factory
TextFieldStyler.transform(Matrix4 value, {Alignment alignment = .center})
factory
TextFieldStyler.translate(double x, double y, [double z = 0.0])
factory
TextFieldStyler.width(double value)
factory

Properties

$animation AnimationConfig?
finalinherited
$container Prop<StyleSpec<BoxSpec>>?
final
$containerEffects Prop<RemixBoxEffectsSpec>?
final
$crossAxisAlignment Prop<CrossAxisAlignment>?
final
$cursorColor Prop<Color>?
final
$cursorHeight Prop<double>?
final
$cursorOpacityAnimates Prop<bool>?
final
$cursorRadius Prop<Radius>?
final
$cursorWidth Prop<double>?
final
$helperText Prop<StyleSpec<TextSpec>>?
final
$hintText Prop<StyleSpec<TextSpec>>?
final
$keyboardAppearance Prop<Brightness>?
final
$label Prop<StyleSpec<TextSpec>>?
final
$layout Prop<StyleSpec<FlexBoxSpec>>?
final
$modifier WidgetModifierConfig?
finalinherited
$scrollPadding Prop<EdgeInsets>?
final
$selectionHeightStyle Prop<BoxHeightStyle>?
final
$selectionWidthStyle Prop<BoxWidthStyle>?
final
$spacing Prop<double>?
final
$text Prop<StyleSpec<TextSpec>>?
final
$textAlign Prop<TextAlign>?
final
$variants List<VariantStyle<TextFieldSpec>>?
finalinherited
hashCode int
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
mergeKey Object
Default implementation uses runtimeType as the merge key
no setterinherited
props List<Object?>
The properties based on which equality and hash code are computed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
Whether to use a detailed string representation of the object.
no setterinherited

Methods

alignment(AlignmentGeometry value) TextFieldStyler
animate(AnimationConfig value) TextFieldStyler
Sets the animation configuration.
override
applyVariants(Iterable<NamedVariant> variantsToApply) TextFieldStyler
Applies the specified named variants by merging their styles into this style.
inherited
backgroundColor(Color value) TextFieldStyler

Available on TextFieldStyler, provided by the RemixTextFieldStylerRemixHelpers extension

Sets background color
backgroundImage(ImageProvider<Object> image, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) TextFieldStyler
backgroundImageAsset(String path, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) TextFieldStyler
backgroundImageUrl(String url, {BoxFit? fit, AlignmentGeometry? alignment, ImageRepeat repeat = .noRepeat}) TextFieldStyler
border(BoxBorderMix<BoxBorder> value) TextFieldStyler
override
borderRadius(BorderRadiusGeometryMix<BorderRadiusGeometry> value) TextFieldStyler
override
build(BuildContext context, {Set<NamedVariant> namedVariants = const {}}) StyleSpec<TextFieldSpec>
Builds the style into a fully resolved spec with metadata.
inherited
call({Key? key, TextEditingController? controller, FocusNode? focusNode, String? label, String? hintText, String? helperText, bool error = false, TextInputType? keyboardType, TextInputAction? textInputAction, TextCapitalization textCapitalization = .none, TextDirection? textDirection, bool obscureText = false, bool enabled = true, bool readOnly = false, bool autofocus = false, int? maxLines = 1, int? minLines, bool expands = false, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, ValueChanged<String>? onChanged, VoidCallback? onEditingComplete, ValueChanged<String>? onSubmitted, AppPrivateCommandCallback? onAppPrivateCommand, List<TextInputFormatter>? inputFormatters, bool? showCursor, String obscuringCharacter = '•', bool autocorrect = true, bool enableSuggestions = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, DragStartBehavior dragStartBehavior = .start, bool enableInteractiveSelection = true, TextSelectionControls? selectionControls, GestureTapCallback? onTap, TapRegionCallback? onTapOutside, TapRegionUpCallback? onPressUpOutside, bool onTapAlwaysCalled = false, ScrollController? scrollController, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, ContentInsertionConfiguration? contentInsertionConfiguration, Clip clipBehavior = .hardEdge, String? restorationId, bool stylusHandwritingEnabled = true, bool enableIMEPersonalizedLearning = true, EditableTextContextMenuBuilder? contextMenuBuilder, SpellCheckConfiguration? spellCheckConfiguration, TextMagnifierConfiguration? magnifierConfiguration, bool canRequestFocus = true, bool? ignorePointers, UndoHistoryController? undoController, Object groupId = EditableText, Widget? leading, Widget? trailing, String? semanticLabel, String? semanticHint, bool excludeSemantics = false}) RemixTextField

Available on TextFieldStyler, provided by the RemixTextFieldStylerRemixHelpers extension

Creates a RemixTextField widget with this style applied.
clipBehavior(Clip value) TextFieldStyler
color(Color value) TextFieldStyler
constraints(BoxConstraintsMix value) TextFieldStyler
override
container(BoxStyler value) TextFieldStyler
Sets the container.
containerEffects(RemixBoxEffectsMix value) TextFieldStyler
Sets the containerEffects.
crossAxisAlignment(CrossAxisAlignment value) TextFieldStyler
Sets the crossAxisAlignment.
cursorColor(Color value) TextFieldStyler
Sets the cursorColor.
cursorHeight(double value) TextFieldStyler
Sets the cursorHeight.
cursorOpacityAnimates(bool value) TextFieldStyler
Sets the cursorOpacityAnimates.
cursorRadius(Radius value) TextFieldStyler
Sets the cursorRadius.
cursorWidth(double value) TextFieldStyler
Sets the cursorWidth.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
decoration(DecorationMix<Decoration> value) TextFieldStyler
override
elevation(ElevationShadow value) TextFieldStyler
foregroundDecoration(DecorationMix<Decoration> value) TextFieldStyler
foregroundLinearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) TextFieldStyler
foregroundRadialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) TextFieldStyler
foregroundSweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) TextFieldStyler
getDiff(Equatable other) Map<String, String>
Returns a map of properties that differ between this object and another.
inherited
gradient(GradientMix<Gradient> value) TextFieldStyler
height(double value) TextFieldStyler
helperText(TextStyler value) TextFieldStyler
Sets the helperText.
hintColor(Color value) TextFieldStyler

Available on TextFieldStyler, provided by the RemixTextFieldStylerRemixHelpers extension

Sets hint text color
hintText(TextStyler value) TextFieldStyler
Sets the hintText.
image(DecorationImageMix value) TextFieldStyler
keyboardAppearance(Brightness value) TextFieldStyler
Sets the keyboardAppearance.
keyframeAnimation({Listenable? trigger, required List<KeyframeTrack> timeline, required KeyframeStyleBuilder<TextFieldSpec, TextFieldStyler> styleBuilder}) TextFieldStyler
Creates a keyframe animation. It will animate through the given timeline.
inherited
label(TextStyler value) TextFieldStyler
Sets the label.
labelColor(Color value) TextFieldStyler
Sets label/text color
inherited
labelDecoration(TextDecoration value) TextFieldStyler
Sets label/text decoration (underline, strikethrough, etc.)
inherited
labelDecorationColor(Color value) TextFieldStyler
Sets label/text decoration color
inherited
labelFontFamily(String value) TextFieldStyler
Sets label/text font family
inherited
labelFontSize(double value) TextFieldStyler
Sets label/text font size
inherited
labelFontStyle(FontStyle value) TextFieldStyler
Sets label/text font style (italic/normal)
inherited
labelFontWeight(FontWeight value) TextFieldStyler
Sets label/text font weight
inherited
labelHeight(double value) TextFieldStyler
Sets label/text line height
inherited
labelLetterSpacing(double value) TextFieldStyler
Sets label/text letter spacing
inherited
labelStyle(TextStyleMix value) TextFieldStyler
Sets label/text style using TextStyleMix directly
inherited
labelWordSpacing(double value) TextFieldStyler
Sets label/text word spacing
inherited
layout(FlexBoxStyler value) TextFieldStyler
Sets the layout.
linearGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? begin, AlignmentGeometry? end, TileMode? tileMode}) TextFieldStyler
margin(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) TextFieldStyler
override
maxHeight(double value) TextFieldStyler
maxWidth(double value) TextFieldStyler
merge(covariant TextFieldStyler? other) TextFieldStyler
Merges with another TextFieldStyler.
override
mergeActiveVariants(BuildContext context, {required Set<NamedVariant> namedVariants}) Style<TextFieldSpec>
Merges all active variants with their nested variants recursively.
inherited
minHeight(double value) TextFieldStyler
minWidth(double value) TextFieldStyler
modifier(WidgetModifierConfig value) TextFieldStyler
Sets the widget modifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAndroid(TextFieldStyler style) TextFieldStyler
Creates a variant for Android platform.
inherited
onBreakpoint(Breakpoint breakpoint, TextFieldStyler style) TextFieldStyler
Creates a variant based on the specified breakpoint.
inherited
onBuilder(TextFieldStyler fn(BuildContext context)) TextFieldStyler
Creates a variant using a builder function that receives the build context.
inherited
onDark(TextFieldStyler style) TextFieldStyler
Creates a variant for dark mode.
inherited
onDesktop(TextFieldStyler style) TextFieldStyler
Creates a variant for desktop breakpoint.
inherited
onDisabled(TextFieldStyler style) TextFieldStyler
Creates a variant for disabled state
inherited
onEnabled(TextFieldStyler style) TextFieldStyler
Creates a variant for enabled state (opposite of disabled)
inherited
onFocused(TextFieldStyler style) TextFieldStyler
Creates a variant for focused state.
inherited
onFocusVisible(TextFieldStyler style) TextFieldStyler
Creates a variant for focus shown in Flutter's traditional highlight mode.
inherited
onFuchsia(TextFieldStyler style) TextFieldStyler
Creates a variant for Fuchsia platform.
inherited
onHovered(TextFieldStyler style) TextFieldStyler
Creates a variant for hover state
inherited
onIos(TextFieldStyler style) TextFieldStyler
Creates a variant for iOS platform.
inherited
onLandscape(TextFieldStyler style) TextFieldStyler
Creates a variant for landscape device orientation.
inherited
onLight(TextFieldStyler style) TextFieldStyler
Creates a variant for light mode.
inherited
onLinux(TextFieldStyler style) TextFieldStyler
Creates a variant for Linux platform.
inherited
onLtr(TextFieldStyler style) TextFieldStyler
Creates a variant for left-to-right text direction.
inherited
onMacos(TextFieldStyler style) TextFieldStyler
Creates a variant for macOS platform.
inherited
onMobile(TextFieldStyler style) TextFieldStyler
Creates a variant for mobile breakpoint.
inherited
onNot(ContextVariant contextVariant, TextFieldStyler style) TextFieldStyler
Creates a variant for when the context does NOT match the provided variant.
inherited
onPortrait(TextFieldStyler style) TextFieldStyler
Creates a variant for portrait device orientation.
inherited
onPressed(TextFieldStyler style) TextFieldStyler
Creates a variant for pressed state
inherited
onRtl(TextFieldStyler style) TextFieldStyler
Creates a variant for right-to-left text direction.
inherited
onTablet(TextFieldStyler style) TextFieldStyler
Creates a variant for tablet breakpoint.
inherited
onWeb(TextFieldStyler style) TextFieldStyler
Creates a variant for web platform.
inherited
onWindows(TextFieldStyler style) TextFieldStyler
Creates a variant for Windows platform.
inherited
padding(EdgeInsetsGeometryMix<EdgeInsetsGeometry> value) TextFieldStyler
override
phaseAnimation<P>({Listenable? trigger, required List<P> phases, required TextFieldStyler styleBuilder(P phase, TextFieldStyler style), required CurveAnimationConfig configBuilder(P phase)}) TextFieldStyler
Creates a phase animation. It will animate through the given phases.
inherited
radialGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? radius, AlignmentGeometry? focal, double? focalRadius, TileMode? tileMode}) TextFieldStyler
resolve(BuildContext context) StyleSpec<TextFieldSpec>
Resolves to StyleSpec<TextFieldSpec> using context.
override
rotate(double radians, {Alignment alignment = .center}) TextFieldStyler
scale(double scale, {Alignment alignment = .center}) TextFieldStyler
scrollPadding(EdgeInsets value) TextFieldStyler
Sets the scrollPadding.
selectionHeightStyle(BoxHeightStyle value) TextFieldStyler
Sets the selectionHeightStyle.
selectionWidthStyle(BoxWidthStyle value) TextFieldStyler
Sets the selectionWidthStyle.
shadow(BoxShadowMix value) TextFieldStyler
shadows(List<BoxShadowMix> value) TextFieldStyler
shape(ShapeBorderMix<ShapeBorder> value) TextFieldStyler
override
size(double width, double height) TextFieldStyler
skew(double skewX, double skewY) TextFieldStyler
spacing(double value) TextFieldStyler
Sets the spacing.
sweepGradient({required List<Color> colors, List<double>? stops, AlignmentGeometry? center, double? startAngle, double? endAngle, TileMode? tileMode}) TextFieldStyler
text(TextStyler value) TextFieldStyler
Sets the text.
textAlign(TextAlign value) TextFieldStyler
Sets the textAlign.
textColor(Color value) TextFieldStyler

Available on TextFieldStyler, provided by the RemixTextFieldStylerRemixHelpers extension

Sets the editable text color.
textStyle(TextStyler value) TextFieldStyler
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
transform(Matrix4 value, {Alignment alignment = .center}) TextFieldStyler
override
translate(double x, double y, [double z = 0.0]) TextFieldStyler
variant(Variant variant, TextFieldStyler style) TextFieldStyler
Must be implemented by the class using this mixin
inherited
variants(List<VariantStyle<TextFieldSpec>> value) TextFieldStyler
Sets the style variants.
override
width(double value) TextFieldStyler
wrap(WidgetModifierConfig value) TextFieldStyler
Wraps with a widget modifier.
override

Operators

operator ==(Object other) bool
Overrides the equality operator to compare based on the properties.
inherited