TextHeightBehaviorMix class
Mix representation of TextHeightBehavior.
Controls text height behavior with tokens.
- Inheritance
-
- Object
- Mixable<
TextHeightBehavior> - Mix<
TextHeightBehavior> - TextHeightBehaviorMix
- Mixed-in types
- Annotations
-
- @Mixable.new(methods: GeneratedMixMethods.skipResolve)
Constructors
- TextHeightBehaviorMix({bool? applyHeightToFirstAscent, bool? applyHeightToLastDescent, TextLeadingDistribution? leadingDistribution})
- TextHeightBehaviorMix.applyHeightToFirstAscent(bool value)
-
Creates with first ascent setting.
factory
- TextHeightBehaviorMix.applyHeightToLastDescent(bool value)
-
Creates with last descent setting.
factory
-
TextHeightBehaviorMix.create({Prop<
bool> ? applyHeightToFirstAscent, Prop<bool> ? applyHeightToLastDescent, Prop<TextLeadingDistribution> ? leadingDistribution}) -
const
- TextHeightBehaviorMix.leadingDistribution(TextLeadingDistribution value)
-
Creates with leading distribution.
factory
- TextHeightBehaviorMix.value(TextHeightBehavior behavior)
- Creates a TextHeightBehaviorMix from an existing TextHeightBehavior.
Properties
-
$applyHeightToFirstAscent
→ Prop<
bool> ? -
final
-
$applyHeightToLastDescent
→ Prop<
bool> ? -
final
-
$leadingDistribution
→ Prop<
TextLeadingDistribution> ? -
final
- hashCode → int
-
Overrides the hash code getter to compute hash code based on properties.
no setterinherited
- mergeKey → Object
-
The key used to identify compatible types for merging.
no setterinherited
-
props
→ List<
Object?> -
The properties based on which equality and hash code are computed.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
Whether to use a detailed string representation of the object.
no setterinherited
Methods
-
applyHeightToFirstAscent(
bool value) → TextHeightBehaviorMix - Copy with first ascent setting.
-
applyHeightToLastDescent(
bool value) → TextHeightBehaviorMix - Copy with last descent setting.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
getDiff(
Equatable other) → Map< String, String> -
Returns a map of properties that differ between this object and another.
inherited
-
leadingDistribution(
TextLeadingDistribution value) → TextHeightBehaviorMix - Copy with leading distribution.
-
merge(
covariant TextHeightBehaviorMix? other) → TextHeightBehaviorMix -
Merges with another text height behavior.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
BuildContext context) → TextHeightBehavior -
Resolves to TextHeightBehavior.
override
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
Overrides the equality operator to compare based on the properties.
inherited
Static Methods
-
maybeValue(
TextHeightBehavior? behavior) → TextHeightBehaviorMix? - Creates from nullable TextHeightBehavior.